@@ -26,6 +26,7 @@
 
 #include "clicommand.h"
 #include <QStringList>
+#include <QStringBuilder>
 #include <QTimer>
 #include <QDir>
 #include <QItemSelectionModel>
@@ -43,7 +44,6 @@
 #include "batchimporter.h"
 #include "downloadclient.h"
 #include "dirrenamer.h"
-#include "audioplayer.h"
 
 namespace {
 
@@ -76,6 +76,7 @@ void CliCommand::clear()
     killTimer(m_timerId);
     m_timerId = 0;
   }
+  cli()->finishWriting();
   m_errorMsg.clear();
   m_args.clear();
   m_result = 0;
@@ -176,8 +177,7 @@ Frame::TagVersion CliCommand::getTagMaskParameter(int nr,
  */
 void CliCommand::showUsage()
 {
-  cli()->writeLine(tr("Usage:"));
-  cli()->writeHelp(name());
+  cli()->writeHelp(name(), true);
   setError(QLatin1String("_Usage"));
 }
 
@@ -212,25 +212,28 @@ void TimeoutCommand::startCommand()
     } else if (val == QLatin1String("default")) {
       cliTimeout = 0;
     } else {
+      QString msStr = val;
+      if (msStr.endsWith(QLatin1String("ms"))) {
+        msStr.truncate(msStr.length() - 2);
+      }
       bool ok;
-      int ms = val.toInt(&ok);
+      int ms = msStr.toInt(&ok);
       if (ok && ms > 0) {
         cliTimeout = ms;
       }
     }
     cli()->setTimeout(cliTimeout);
   }
-  QString msg(tr("Timeout"));
-  msg += QLatin1String(": ");
+  QString value;
   if (cliTimeout < 0) {
-    msg += QLatin1String("off");
+    value = QLatin1String("off");
   } else if (cliTimeout == 0) {
-    msg += QLatin1String("default");
+    value = QLatin1String("default");
   } else {
-    msg += QString::number(cliTimeout);
-    msg += QLatin1String(" ms");
+    value = QString::number(cliTimeout);
+    value += QLatin1String(" ms");
   }
-  cli()->writeLine(msg);
+  cli()->writeResult(QVariantMap{{QLatin1String("timeout"), value}});
 }
 
 
@@ -244,8 +247,9 @@ void QuitCommand::startCommand()
 {
   if (cli()->app()->isModified() && !cli()->app()->getDirName().isEmpty()) {
     if (!(args().size() > 1 && args().at(1) == QLatin1String("force"))) {
-      cli()->writeLine(tr("The current directory has been modified."));
-      cli()->writeLine(tr("Type 'exit force' to quit."));
+      cli()->writeResult(tr("The current folder has been modified.") %
+                         QLatin1Char('\n') %
+                         tr("Type 'exit force' to quit."));
       terminate();
       return;
     }
@@ -261,7 +265,7 @@ void QuitCommand::connectResultSignal()
 
 
 CdCommand::CdCommand(Kid3Cli* processor)
-  : CliCommand(processor, QLatin1String("cd"), tr("Change directory"),
+  : CliCommand(processor, QLatin1String("cd"), tr("Change folder"),
                QLatin1String("[P]"))
 {
 }
@@ -295,7 +299,7 @@ void CdCommand::disconnectResultSignal()
 
 PwdCommand::PwdCommand(Kid3Cli* processor)
   : CliCommand(processor, QLatin1String("pwd"),
-               tr("Print the filename of the current working directory"))
+               tr("Print the filename of the current folder"))
 {
 }
 
@@ -306,12 +310,12 @@ void PwdCommand::startCommand()
     path = QDir::currentPath();
     cli()->app()->openDirectory({path});
   }
-  cli()->writeLine(path);
+  cli()->writeResult(path);
 }
 
 
 LsCommand::LsCommand(Kid3Cli* processor)
-  : CliCommand(processor, QLatin1String("ls"), tr("Directory list"))
+  : CliCommand(processor, QLatin1String("ls"), tr("Folder list"))
 {
   setTimeout(10000);
 }
@@ -409,7 +413,7 @@ void GetCommand::startCommand()
       QString value = cli()->app()->getFrame(Frame::tagVersionFromNumber(tagNr),
                                              name);
       if (!(tagNr == Frame::Tag_1 ? value.isEmpty() : value.isNull())) {
-        cli()->writeLine(value);
+        cli()->writeResult(value);
         break;
       }
     }
@@ -469,11 +473,19 @@ ImportCommand::ImportCommand(Kid3Cli* processor)
 void ImportCommand::startCommand()
 {
   int numArgs = args().size();
-  if (numArgs > 3 && args().at(1) == QLatin1String("tags")) {
+  if (numArgs > 3 && args().at(1).startsWith(QLatin1String("tags"))) {
     const QString& source = args().at(2);
     const QString& extraction = args().at(3);
     Frame::TagVersion tagMask = getTagMaskParameter(4);
-    cli()->app()->importFromTags(tagMask, source, extraction);
+    if (args().at(1).contains(QLatin1String("sel"))) {
+      QStringList returnValues =
+          cli()->app()->importFromTagsToSelection(tagMask, source, extraction);
+      if (!returnValues.isEmpty()) {
+        cli()->writeResult(returnValues);
+      }
+    } else {
+      cli()->app()->importFromTags(tagMask, source, extraction);
+    }
   } else if (numArgs > 2) {
     const QString& path = args().at(1);
     const QString& fmtName = args().at(2);
@@ -550,44 +562,44 @@ void BatchImportCommand::disconnectResultSignal()
 
 void BatchImportCommand::onReportImportEvent(int type, const QString& text)
 {
-  QString eventText;
+  QString typeStr;
   switch (type) {
   case BatchImporter::ReadingDirectory:
-    eventText = tr("Reading Directory");
+    typeStr = QLatin1String("readingDirectory");
     break;
   case BatchImporter::Started:
-    eventText = tr("Started");
+    typeStr = QLatin1String("started");
     break;
   case BatchImporter::SourceSelected:
-    eventText = tr("Source");
+    typeStr = QLatin1String("source");
     break;
   case BatchImporter::QueryingAlbumList:
-    eventText = tr("Querying");
+    typeStr = QLatin1String("querying");
     break;
   case BatchImporter::FetchingTrackList:
   case BatchImporter::FetchingCoverArt:
-    eventText = tr("Fetching");
+    typeStr = QLatin1String("fetching");
     break;
   case BatchImporter::TrackListReceived:
-    eventText = tr("Data received");
+    typeStr = QLatin1String("data received");
     break;
   case BatchImporter::CoverArtReceived:
-    eventText = tr("Cover");
+    typeStr = QLatin1String("cover");
     break;
   case BatchImporter::Finished:
-    eventText = tr("Finished");
+    typeStr = QLatin1String("finished");
     break;
   case BatchImporter::Aborted:
-    eventText = tr("Aborted");
+    typeStr = QLatin1String("aborted");
     break;
   case BatchImporter::Error:
-    eventText = tr("Error");
+    typeStr = QLatin1String("error");
   }
+  QVariantMap event{{QLatin1String("type"), typeStr}};
   if (!text.isEmpty()) {
-    eventText += QLatin1String(": ");
-    eventText += text;
+    event.insert(QLatin1String("data"), text);
   }
-  cli()->writeLine(eventText);
+  cli()->writeResult(QVariantMap{{QLatin1String("event"), event}});
 }
 
 
@@ -723,7 +735,7 @@ void TextEncodingCommand::startCommand()
 
 
 RenameDirectoryCommand::RenameDirectoryCommand(Kid3Cli* processor)
-  : CliCommand(processor, QLatin1String("renamedir"), tr("Rename directory"),
+  : CliCommand(processor, QLatin1String("renamedir"), tr("Rename folder"),
        QLatin1String("[F] [S] [T]\nS = \"create\" | \"rename\" | \"dryrun\"")),
     m_dryRun(false)
 {
@@ -786,16 +798,18 @@ void RenameDirectoryCommand::disconnectResultSignal()
 
 void RenameDirectoryCommand::onActionScheduled(const QStringList& actionStrs)
 {
-  QString str = actionStrs.at(0);
+  QVariantMap event{{QLatin1String("type"), actionStrs.at(0)}};
+  QVariantMap data;
   if (actionStrs.size() > 1) {
-    str += QLatin1String("  ");
-    str += actionStrs.at(1);
+    data.insert(QLatin1String("source"), actionStrs.at(1));
   }
   if (actionStrs.size() > 2) {
-    str += QLatin1String("\n  ");
-    str += actionStrs.at(2);
+    data.insert(QLatin1String("destination"), actionStrs.at(2));
   }
-  cli()->writeLine(str);
+  if (!data.isEmpty()) {
+    event.insert(QLatin1String("data"), data);
+  }
+  cli()->writeResult(QVariantMap{{QLatin1String("event"), event}});
 }
 
 void RenameDirectoryCommand::onRenameActionsScheduled()
@@ -887,34 +901,42 @@ void FilterCommand::disconnectResultSignal()
 
 void FilterCommand::onFileFiltered(int type, const QString& fileName)
 {
-  QString eventText;
+  QString typeStr;
+  QString data;
   bool finish = false;
   switch (type) {
   case FileFilter::Started:
-    eventText = tr("Started");
+    typeStr = QLatin1String("started");
     break;
   case FileFilter::Directory:
-    eventText = QLatin1String("  ") + fileName;
+    typeStr = QLatin1String("filterEntered");
+    data = fileName;
     break;
   case FileFilter::ParseError:
-    eventText = QLatin1String("parse error");
+    typeStr = QLatin1String("parseError");
     break;
   case FileFilter::FilePassed:
-    eventText = QLatin1String("+ ") + fileName;
+    typeStr = QLatin1String("filterPassed");
+    data = fileName;
     break;
   case FileFilter::FileFilteredOut:
-    eventText = QLatin1String("- ") + fileName;
+    typeStr = QLatin1String("filteredOut");
+    data = fileName;
     break;
   case FileFilter::Finished:
-    eventText = tr("Finished");
+    typeStr = QLatin1String("finished");
     finish = true;
     break;
   case FileFilter::Aborted:
-    eventText = tr("Aborted");
+    typeStr = QLatin1String("aborted");
     finish = true;
     break;
   }
-  cli()->writeLine(eventText);
+  QVariantMap event{{QLatin1String("type"), typeStr}};
+  if (!data.isEmpty()) {
+    event.insert(QLatin1String("data"), data);
+  }
+  cli()->writeResult(QVariantMap{{QLatin1String("event"), event}});
   if (finish) {
     terminate();
   }
@@ -1057,40 +1079,3 @@ void RemoveCommand::startCommand()
   Frame::TagVersion tagMask = getTagMaskParameter(1);
   cli()->app()->removeTags(tagMask);
 }
-
-
-PlayCommand::PlayCommand(Kid3Cli* processor)
-  : CliCommand(processor, QLatin1String("play"), tr("Play"),
-               QLatin1String("[S]\n"
-               "S = \"pause\" | \"stop\" | \"previous\" | \"next\""))
-{
-}
-
-void PlayCommand::startCommand()
-{
-  AudioPlayer* player = nullptr;
-  QString param;
-  if (args().size() > 1) {
-    param = args().at(1);
-    player = cli()->app()->getAudioPlayer();
-  }
-  if (param == QLatin1String("pause")) {
-    if (player) {
-      player->playOrPause();
-    }
-  } else if (param == QLatin1String("stop")) {
-    if (player) {
-      player->stop();
-    }
-  } else if (param == QLatin1String("previous")) {
-    if (player) {
-      player->previous();
-    }
-  } else if (param == QLatin1String("next")) {
-    if (player) {
-      player->next();
-    }
-  } else {
-    cli()->app()->playAudio();
-  }
-}
