@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Sep 2003
  *
- * Copyright (C) 2003-2012  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,20 +24,15 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef KDECONFIGDIALOG_H
-#define KDECONFIGDIALOG_H
+#pragma once
 
 #include <QtGlobal>
-#if QT_VERSION >= 0x050000
 #include <KConfigDialog>
-#include <KConfigSkeleton>
-#else
-#include <kconfigdialog.h>
-#endif
 
 class QString;
 class QWidget;
 class QComboBox;
+class KConfigSkeleton;
 class ConfigDialogPages;
 class IPlatformTools;
 
@@ -61,7 +56,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~KdeConfigDialog();
+  virtual ~KdeConfigDialog() override = default;
 
   /**
    * Set values in dialog from current configuration.
@@ -85,10 +80,8 @@ protected:
    * the same as the default configuration.
    * @return false
    */
-  virtual bool isDefault();
+  virtual bool isDefault() override;
 
 private:
   ConfigDialogPages* m_pages;
 };
-
-#endif
