@@ -60,6 +60,7 @@ KdeMainWindow::KdeMainWindow(IPlatformTools* platformTools,
   : KXmlGuiWindow(parent),
     BaseMainWindow(this, platformTools, app),
     m_platformTools(platformTools), m_fileOpenRecent(nullptr),
+    m_settingsShowStatusbar(nullptr),
     m_settingsAutoHideTags(nullptr), m_settingsShowHidePicture(nullptr)
 {
   init();
@@ -89,7 +90,7 @@ void KdeMainWindow::initActions()
   m_fileOpenRecent = KStandardAction::openRecent(
       this, SLOT(slotFileOpenRecentUrl(QUrl)), collection);
 #endif
-  m_fileOpenRecent->setStatusTip(tr("Opens a recently used directory"));
+  m_fileOpenRecent->setStatusTip(tr("Opens a recently used folder"));
 #if KCONFIGWIDGETS_VERSION >= 0x051700
   action = KStandardAction::revert(
       app(), &Kid3Application::revertFileModifications, collection);
@@ -168,6 +169,14 @@ void KdeMainWindow::initActions()
     this, SLOT(slotSettingsToolbars()), collection);
 #endif
   action->setStatusTip(tr("Configure Toolbars"));
+#if KCONFIGWIDGETS_VERSION >= 0x051700
+  m_settingsShowStatusbar = KStandardAction::showStatusbar(
+    this, &KdeMainWindow::slotSettingsShowStatusbar, collection);
+#else
+  m_settingsShowStatusbar = KStandardAction::showStatusbar(
+    this, SLOT(slotSettingsShowStatusbar()), collection);
+#endif
+  m_settingsShowStatusbar->setStatusTip(tr("Enables/disables the statusbar"));
 #if KCONFIGWIDGETS_VERSION >= 0x051700
   action = KStandardAction::preferences(
       this, &KdeMainWindow::slotSettingsConfigure, collection);
@@ -178,8 +187,8 @@ void KdeMainWindow::initActions()
   action->setStatusTip(tr("Preferences dialog"));
 
   action = new QAction(QIcon::fromTheme(QLatin1String("document-open")),
-                       tr("O&pen Directory..."), this);
-  action->setStatusTip(tr("Opens a directory"));
+                       tr("O&pen Folder..."), this);
+  action->setStatusTip(tr("Opens a folder"));
   action->setShortcut(QKeySequence(QLatin1String("Ctrl+D")));
   collection->addAction(QLatin1String("open_directory"), action);
   connect(action, &QAction::triggered,
@@ -187,7 +196,7 @@ void KdeMainWindow::initActions()
 
   action = new QAction(QIcon::fromTheme(QLatin1String("view-refresh")),
                        tr("Re&load"), this);
-  action->setStatusTip(tr("Reload directory"));
+  action->setStatusTip(tr("Reload folder"));
   action->setShortcut(QKeySequence::Refresh);
   collection->addAction(QLatin1String("reload"), action);
   connect(action, &QAction::triggered,
@@ -239,6 +248,11 @@ void KdeMainWindow::initActions()
     ++importerIdx;
   }
 
+  action = new QAction(tr("Import from Tags..."), this);
+  action->setStatusTip(tr("Import from Tags"));
+  collection->addAction(QLatin1String("import_tags"), action);
+  connect(action, &QAction::triggered, impl(), &BaseMainWindowImpl::slotTagImport);
+
   action = new QAction(tr("Automatic I&mport..."), this);
   action->setStatusTip(tr("Automatic import"));
   collection->addAction(QLatin1String("batch_import"), action);
@@ -270,8 +284,8 @@ void KdeMainWindow::initActions()
   action->setStatusTip(tr("Apply Text Encoding"));
   collection->addAction(QLatin1String("apply_text_encoding"), action);
   connect(action, &QAction::triggered, app(), &Kid3Application::applyTextEncoding);
-  action = new QAction(tr("&Rename Directory..."), this);
-  action->setStatusTip(tr("Rename Directory"));
+  action = new QAction(tr("&Rename Folder..."), this);
+  action->setStatusTip(tr("Rename Folder"));
   collection->addAction(QLatin1String("rename_directory"), action);
   connect(action, &QAction::triggered, impl(), &BaseMainWindowImpl::slotRenameDirectory);
   action = new QAction(tr("&Number Tracks..."), this);
@@ -312,8 +326,8 @@ void KdeMainWindow::initActions()
   collection->addAction(QLatin1String("auto_hide_tags"), m_settingsAutoHideTags);
   connect(m_settingsAutoHideTags, &QAction::triggered,
           impl(), &BaseMainWindowImpl::slotSettingsAutoHideTags);
-  action = new QAction(tr("Select All in &Directory"), this);
-  action->setStatusTip(tr("Select all files in the current directory"));
+  action = new QAction(tr("Select All in &Folder"), this);
+  action->setStatusTip(tr("Select all files in the current folder"));
   collection->addAction(QLatin1String("select_all_in_directory"), action);
   connect(action, &QAction::triggered, app(), &Kid3Application::selectAllInDirectory);
   action = new QAction(QIcon::fromTheme(QLatin1String("go-previous")),
@@ -412,7 +426,7 @@ void KdeMainWindow::initActions()
   connect(action, &QAction::triggered, impl(), &BaseMainWindowImpl::deleteFile);
   collection->addAction(QLatin1String("filelist_delete"), action);
   form()->getFileList()->setDeleteAction(action);
-  action = new QAction(tr("Directory List") + QLatin1String(": ") + tr("Focus"),
+  action = new QAction(tr("Folder List") + QLatin1String(": ") + tr("Focus"),
                        this);
   collection->addAction(QLatin1String("dirlist_focus"), action);
   connect(action, &QAction::triggered, form(), &Kid3Form::setFocusDirList);
@@ -452,7 +466,15 @@ void KdeMainWindow::readConfig()
   setAutoSaveSettings();
   m_settingsShowHidePicture->setChecked(!GuiConfig::instance().hidePicture());
   m_settingsAutoHideTags->setChecked(GuiConfig::instance().autoHideTags());
-  m_fileOpenRecent->loadEntries(KSharedConfig::openConfig()->group("Recent Files"));
+  auto cfg = KSharedConfig::openConfig();
+  m_fileOpenRecent->loadEntries(cfg->group("Recent Files"));
+
+  QString entry = cfg->group("MainWindow").readEntry("StatusBar", "Enabled");
+  bool statusBarVisible = entry != QLatin1String("Disabled");
+  if (m_settingsShowStatusbar) {
+    m_settingsShowStatusbar->setChecked(statusBarVisible);
+  }
+  setStatusBarVisible(statusBarVisible);
 }
 
 /**
@@ -559,6 +581,15 @@ void KdeMainWindow::slotSettingsToolbars()
   }
 }
 
+/**
+ * Statusbar configuration.
+ */
+void KdeMainWindow::slotSettingsShowStatusbar()
+{
+  setStatusBarVisible(m_settingsShowStatusbar->isChecked());
+  setSettingsDirty();
+}
+
 /**
  * Preferences.
  */
