@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Sep 2003
  *
- * Copyright (C) 2003-2013  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -55,16 +55,16 @@
  * @param shortcutsModel shortcuts model
  */
 ConfigDialog::ConfigDialog(IPlatformTools* platformTools, QWidget* parent,
-                           QString& caption, ShortcutsModel* shortcutsModel) :
-  QDialog(parent),
-  m_pages(new ConfigDialogPages(platformTools, this)),
-  m_shortcutsModel(shortcutsModel)
+                           QString& caption, ShortcutsModel* shortcutsModel)
+  : QDialog(parent),
+    m_pages(new ConfigDialogPages(platformTools, this)),
+    m_shortcutsModel(shortcutsModel)
 {
   setObjectName(QLatin1String("ConfigDialog"));
   setWindowTitle(caption);
   setSizeGripEnabled(true);
-  QVBoxLayout* topLayout = new QVBoxLayout(this);
-  QTabWidget* tabWidget = new QTabWidget(this);
+  auto topLayout = new QVBoxLayout(this);
+  auto tabWidget = new QTabWidget(this);
   tabWidget->setUsesScrollButtons(false);
 
   tabWidget->addTab(m_pages->createTagsPage(), tr("&Tags"));
@@ -75,7 +75,7 @@ ConfigDialog::ConfigDialog(IPlatformTools* platformTools, QWidget* parent,
 
   {
     QWidget* shortcutsPage = new QWidget;
-    QVBoxLayout* vlayout = new QVBoxLayout(shortcutsPage);
+    auto vlayout = new QVBoxLayout(shortcutsPage);
     m_shortcutsTreeView = new QTreeView;
     m_shortcutsTreeView->setSelectionMode(QAbstractItemView::NoSelection);
     m_shortcutsTreeView->setItemDelegateForColumn(
@@ -86,15 +86,15 @@ ConfigDialog::ConfigDialog(IPlatformTools* platformTools, QWidget* parent,
     tabWidget->addTab(shortcutsPage, tr("&Keyboard Shortcuts"));
 
     connect(m_shortcutsModel,
-            SIGNAL(shortcutAlreadyUsed(QString,QString,const QAction*)),
+            &ShortcutsModel::shortcutAlreadyUsed,
             this,
-            SLOT(warnAboutAlreadyUsedShortcut(QString,QString,const QAction*)));
+            &ConfigDialog::warnAboutAlreadyUsedShortcut);
     connect(m_shortcutsModel,
-            SIGNAL(shortcutSet(QString,QString,const QAction*)),
+            &ShortcutsModel::shortcutSet,
             this,
-            SLOT(clearAlreadyUsedShortcutWarning()));
-    connect(this, SIGNAL(rejected()),
-            m_shortcutsModel, SLOT(discardChangedShortcuts()));
+            &ConfigDialog::clearAlreadyUsedShortcutWarning);
+    connect(this, &QDialog::rejected,
+            m_shortcutsModel, &ShortcutsModel::discardChangedShortcuts);
     m_shortcutsTreeView->setModel(m_shortcutsModel);
     m_shortcutsTreeView->expandAll();
     m_shortcutsTreeView->resizeColumnToContents(ShortcutsModel::ActionColumn);
@@ -105,12 +105,15 @@ ConfigDialog::ConfigDialog(IPlatformTools* platformTools, QWidget* parent,
 
   {
     QWidget* appearancePage = new QWidget;
-    QVBoxLayout* vlayout = new QVBoxLayout(appearancePage);
-    QGridLayout* fontStyleLayout = new QGridLayout;
+    auto vlayout = new QVBoxLayout(appearancePage);
+    auto fontStyleLayout = new QGridLayout;
 
-    m_useApplicationFontCheckBox = new QCheckBox(tr("Use custom app&lication font"), appearancePage);
-    m_applicationFontButton = new QPushButton(tr("A&pplication Font..."), appearancePage);
-    m_useApplicationStyleCheckBox = new QCheckBox(tr("Use custom application &style"), appearancePage);
+    m_useApplicationFontCheckBox =
+        new QCheckBox(tr("Use custom app&lication font"), appearancePage);
+    m_applicationFontButton =
+        new QPushButton(tr("A&pplication Font..."), appearancePage);
+    m_useApplicationStyleCheckBox =
+        new QCheckBox(tr("Use custom application &style"), appearancePage);
     m_applicationStyleComboBox = new QComboBox(appearancePage);
     fontStyleLayout->addWidget(m_useApplicationFontCheckBox, 0, 0);
     fontStyleLayout->addWidget(m_applicationFontButton, 0, 1);
@@ -118,16 +121,21 @@ ConfigDialog::ConfigDialog(IPlatformTools* platformTools, QWidget* parent,
     fontStyleLayout->addWidget(m_applicationStyleComboBox, 1, 1);
     m_applicationStyleComboBox->addItem(tr("Unknown"));
     m_applicationStyleComboBox->addItems(QStyleFactory::keys());
-    connect(m_applicationFontButton, SIGNAL(clicked()), this, SLOT(slotSelectFont()));
-    connect(m_applicationStyleComboBox, SIGNAL(activated(QString)), this, SLOT(slotSelectStyle(QString)));
-    connect(m_useApplicationFontCheckBox, SIGNAL(toggled(bool)), m_applicationFontButton, SLOT(setEnabled(bool)));
-    connect(m_useApplicationStyleCheckBox, SIGNAL(toggled(bool)), m_applicationStyleComboBox, SLOT(setEnabled(bool)));
+    connect(m_applicationFontButton, &QAbstractButton::clicked,
+            this, &ConfigDialog::slotSelectFont);
+    connect(m_applicationStyleComboBox,
+            static_cast<void (QComboBox::*)(const QString&)>(&QComboBox::activated),
+            this, &ConfigDialog::slotSelectStyle);
+    connect(m_useApplicationFontCheckBox, &QAbstractButton::toggled,
+            m_applicationFontButton, &QWidget::setEnabled);
+    connect(m_useApplicationStyleCheckBox, &QAbstractButton::toggled,
+            m_applicationStyleComboBox, &QWidget::setEnabled);
     vlayout->addLayout(fontStyleLayout);
 
     m_useNativeDialogsCheckBox =
         new QCheckBox(tr("Use native system file &dialogs"), appearancePage);
     vlayout->addWidget(m_useNativeDialogsCheckBox);
-    QSpacerItem* vspacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);
+    auto vspacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);
     vlayout->addItem(vspacer);
     tabWidget->addTab(appearancePage, tr("&Appearance"));
   }
@@ -135,8 +143,8 @@ ConfigDialog::ConfigDialog(IPlatformTools* platformTools, QWidget* parent,
   m_styleChanged = false;
 
   topLayout->addWidget(tabWidget);
-  QHBoxLayout* hlayout = new QHBoxLayout;
-  QSpacerItem* hspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
+  auto hlayout = new QHBoxLayout;
+  auto hspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
                                          QSizePolicy::Minimum);
   QPushButton* helpButton = new QPushButton(tr("&Help"), this);
   QPushButton* defaultsButton = new QPushButton(tr("Restore Defaults"), this);
@@ -148,23 +156,18 @@ ConfigDialog::ConfigDialog(IPlatformTools* platformTools, QWidget* parent,
   hlayout->addWidget(okButton);
   hlayout->addWidget(cancelButton);
   okButton->setDefault(true);
-  connect(helpButton, SIGNAL(clicked()), this, SLOT(slotHelp()));
-  connect(defaultsButton, SIGNAL(clicked()),
-          m_pages, SLOT(setDefaultConfig()));
-  connect(defaultsButton, SIGNAL(clicked()),
-          this, SLOT(setDefaultConfig()));
-  connect(okButton, SIGNAL(clicked()), this, SLOT(accept()));
-  connect(cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
-  connect(cancelButton, SIGNAL(clicked()), this, SLOT(slotRevertFontAndStyle()));
+  connect(helpButton, &QAbstractButton::clicked, this, &ConfigDialog::slotHelp);
+  connect(defaultsButton, &QAbstractButton::clicked,
+          m_pages, &ConfigDialogPages::setDefaultConfig);
+  connect(defaultsButton, &QAbstractButton::clicked,
+          this, &ConfigDialog::setDefaultConfig);
+  connect(okButton, &QAbstractButton::clicked, this, &QDialog::accept);
+  connect(cancelButton, &QAbstractButton::clicked, this, &QDialog::reject);
+  connect(cancelButton, &QAbstractButton::clicked,
+          this, &ConfigDialog::slotRevertFontAndStyle);
   topLayout->addLayout(hlayout);
 }
 
-/**
- * Destructor.
- */
-ConfigDialog::~ConfigDialog()
-{}
-
 /**
  * Set values in dialog from current configuration.
  */
@@ -251,9 +254,10 @@ void ConfigDialog::warnAboutAlreadyUsedShortcut(
     const QString& key, const QString& context, const QAction* action)
 {
   m_shortcutAlreadyUsedLabel->setText(
-        tr("The keyboard shortcut '%1' is already assigned to '%2'.").
-        arg(key).
-        arg(context + QLatin1Char('/') + (action ? action->text().remove(QLatin1Char('&')) : QLatin1String("?"))));
+        tr("The keyboard shortcut '%1' is already assigned to '%2'.")
+        .arg(key, context + QLatin1Char('/') +
+            (action ? action->text().remove(QLatin1Char('&'))
+                    : QLatin1String("?"))));
 }
 
 /**
