@@ -65,6 +65,46 @@ ISettings* PlatformTools::applicationSettings()
   return CorePlatformTools::applicationSettings();
 }
 
+/**
+ * Get icon provider for tagged files.
+ * @return icon provider.
+ */
+CoreTaggedFileIconProvider* PlatformTools::iconProvider()
+{
+  return GuiPlatformTools::iconProvider();
+}
+
+/**
+ * Write text to clipboard.
+ * @param text text to write
+ * @return true if operation is supported.
+ */
+bool PlatformTools::writeToClipboard(const QString& text) const
+{
+  return GuiPlatformTools::writeToClipboard(text);
+}
+
+/**
+ * Read text from clipboard.
+ * @return text, null if operation not supported.
+ */
+QString PlatformTools::readFromClipboard() const
+{
+  return GuiPlatformTools::readFromClipboard();
+}
+
+/**
+ * Create an audio player instance.
+ * @param app application context
+ * @param dbusEnabled true to enable MPRIS D-Bus interface
+ * @return audio player, nullptr if not supported.
+ */
+QObject* PlatformTools::createAudioPlayer(Kid3Application* app,
+                                   bool dbusEnabled) const
+{
+  return GuiPlatformTools::createAudioPlayer(app, dbusEnabled);
+}
+
 /**
  * Move file or directory to trash.
  *
