@@ -28,7 +28,7 @@
 
 #include <QScopedPointer>
 #include "iplatformtools.h"
-#include "coreplatformtools.h"
+#include "guiplatformtools.h"
 
 class QSettings;
 class BrowserDialog;
@@ -36,7 +36,7 @@ class BrowserDialog;
 /**
  * Platform specific tools.
  */
-class PlatformTools : public IPlatformTools, private CorePlatformTools {
+class PlatformTools : public IPlatformTools, private GuiPlatformTools {
 public:
   /**
    * Constructor.
@@ -54,6 +54,34 @@ public:
    */
   virtual ISettings* applicationSettings() override;
 
+  /**
+   * Get icon provider for tagged files.
+   * @return icon provider.
+   */
+  virtual CoreTaggedFileIconProvider* iconProvider() override;
+
+  /**
+   * Write text to clipboard.
+   * @param text text to write
+   * @return true if operation is supported.
+   */
+  virtual bool writeToClipboard(const QString& text) const override;
+
+  /**
+   * Read text from clipboard.
+   * @return text, null if operation not supported.
+   */
+  virtual QString readFromClipboard() const override;
+
+  /**
+   * Create an audio player instance.
+   * @param app application context
+   * @param dbusEnabled true to enable MPRIS D-Bus interface
+   * @return audio player, nullptr if not supported.
+   */
+  virtual QObject* createAudioPlayer(Kid3Application* app,
+                                     bool dbusEnabled) const override;
+
   /**
    * Move file or directory to trash.
    *
