@@ -42,8 +42,8 @@ class FrameCollection;
 class KID3_CORE_EXPORT FormatConfig : public GeneralConfig {
   Q_OBJECT
   /** Mapping for string replacement */
-  Q_PROPERTY(QVariantMap strRepMap READ strRepVariantMap
-             WRITE setStrRepVariantMap NOTIFY strRepMapChanged)
+  Q_PROPERTY(QStringList strRepMap READ strRepStringList
+             WRITE setStrRepStringList NOTIFY strRepMapChanged)
   /** Case conversion option */
   Q_PROPERTY(int caseConversion READ caseConversion WRITE setCaseConversionInt
              NOTIFY caseConversionChanged)
@@ -144,16 +144,16 @@ public:
   virtual void readFromConfig(ISettings* config) override;
 
   /** Get mapping for string replacement. */
-  QMap<QString, QString> strRepMap() const { return m_strRepMap; }
+  QList<QPair<QString, QString>> strRepMap() const { return m_strRepMap; }
 
   /** Set mapping for string replacement. */
-  void setStrRepMap(const QMap<QString, QString>& strRepMap);
+  void setStrRepMap(const QList<QPair<QString, QString>>& strRepMap);
 
-  /** Get mapping for string replacement as a variant map. */
-  QVariantMap strRepVariantMap() const;
+  /** Get mapping for string replacement as a list with alternating key, values. */
+  QStringList strRepStringList() const;
 
-  /** Set mapping for string replacement from a variant map. */
-  void setStrRepVariantMap(const QVariantMap& map);
+  /** Set mapping for string replacement from a list with alternating key, values. */
+  void setStrRepStringList(const QStringList& lst);
 
   /** Get case conversion option. */
   CaseConversion caseConversion() const { return m_caseConversion; }
@@ -215,7 +215,7 @@ public:
 
 signals:
   /** Emitted when @a strRepMap changed. */
-  void strRepMapChanged(const QMap<QString, QString>& strRepMap);
+  void strRepMapChanged(const QList<QPair<QString, QString>>& strRepMap);
 
   /** Emitted when @a caseConversion changed. */
   void caseConversionChanged(FormatConfig::CaseConversion caseConversion);
@@ -249,7 +249,7 @@ private:
     setCaseConversion(static_cast<CaseConversion>(caseConversion));
   }
 
-  QMap<QString, QString> m_strRepMap;
+  QList<QPair<QString, QString>> m_strRepMap;
   CaseConversion m_caseConversion;
   QString m_localeName;
   /** Locale to use for string conversions */
