@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Sep 2003
  *
- * Copyright (C) 2003-2007  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -42,11 +42,6 @@ enum { TextEncodingLatin1Index = 13 };
  */
 GeneralConfig::GeneralConfig(const QString& grp) : m_group(grp) {}
 
-/**
- * Destructor.
- */
-GeneralConfig::~GeneralConfig() {}
-
 /**
  * Convert list of integers to list of strings.
  * @param intList list of integers
@@ -55,7 +50,8 @@ GeneralConfig::~GeneralConfig() {}
 QStringList GeneralConfig::intListToStringList(const QList<int>& intList)
 {
   QStringList result;
-  foreach (int value, intList) {
+  result.reserve(intList.size());
+  for (int value : intList) {
     result.append(QString::number(value));
   }
   return result;
@@ -69,7 +65,8 @@ QStringList GeneralConfig::intListToStringList(const QList<int>& intList)
 QList<int> GeneralConfig::stringListToIntList(const QStringList& strList)
 {
   QList<int> result;
-  foreach (const QString& value, strList) {
+  result.reserve(strList.size());
+  for (const QString& value : strList) {
     result.append(value.toInt());
   }
   return result;
@@ -142,7 +139,7 @@ QStringList GeneralConfig::getTextCodecNames()
       "windows-1257",
       "windows-1258",
       "WINSAMI2 (WS2)",
-      0
+      nullptr
     };
     Q_ASSERT(qstrcmp(codecs[TextEncodingLatin1Index], "ISO-8859-1 (latin1)") == 0);
     const char* const* str = codecs;
@@ -175,7 +172,7 @@ int GeneralConfig::indexFromTextCodecName(const QString& textEncoding)
 {
   int index = 0;
   QStringList textEncodingList = getTextCodecNames();
-  for (QStringList::const_iterator it = textEncodingList.constBegin();
+  for (auto it = textEncodingList.constBegin();
        it != textEncodingList.constEnd();
        ++it) {
     if (getTextCodecName(*it) == textEncoding) {
