@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 29 Jun 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,27 +24,30 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef NUMBERTRACKSCONFIG_H
-#define NUMBERTRACKSCONFIG_H
+#pragma once
 
 #include "generalconfig.h"
-#include "trackdata.h"
+#include "frame.h"
 #include "kid3api.h"
 
 /**
  * Configuration for track numbering.
  */
-class KID3_CORE_EXPORT NumberTracksConfig :
-  public StoredConfig<NumberTracksConfig> {
+class KID3_CORE_EXPORT NumberTracksConfig
+    : public StoredConfig<NumberTracksConfig> {
   Q_OBJECT
   /** number tracks in tags 1, tags 2, or both */
-  Q_PROPERTY(int numberTracksDestination READ numberTracksDestination WRITE setNumberTracksDstInt NOTIFY numberTracksDestinationChanged)
+  Q_PROPERTY(int numberTracksDestination READ numberTracksDestination
+             WRITE setNumberTracksDstInt NOTIFY numberTracksDestinationChanged)
   /** number tracks start number */
-  Q_PROPERTY(int numberTracksStart READ numberTracksStart WRITE setNumberTracksStart NOTIFY numberTracksStartChanged)
+  Q_PROPERTY(int numberTracksStart READ numberTracksStart
+             WRITE setNumberTracksStart NOTIFY numberTracksStartChanged)
   /** enable track numbering */
-  Q_PROPERTY(bool trackNumberingEnabled READ isTrackNumberingEnabled WRITE setTrackNumberingEnabled NOTIFY trackNumberingEnabledChanged)
+  Q_PROPERTY(bool trackNumberingEnabled READ isTrackNumberingEnabled
+             WRITE setTrackNumberingEnabled NOTIFY trackNumberingEnabledChanged)
   /** reset of counter for each directory */
-  Q_PROPERTY(bool directoryCounterResetEnabled READ isDirectoryCounterResetEnabled WRITE setDirectoryCounterResetEnabled NOTIFY directoryCounterResetEnabledChanged)
+  Q_PROPERTY(bool directoryCounterResetEnabled READ isDirectoryCounterResetEnabled
+             WRITE setDirectoryCounterResetEnabled NOTIFY directoryCounterResetEnabledChanged)
 public:
   /**
    * Constructor.
@@ -54,21 +57,21 @@ public:
   /**
    * Destructor.
    */
-  virtual ~NumberTracksConfig();
+  virtual ~NumberTracksConfig() override = default;
 
   /**
    * Persist configuration.
    *
    * @param config configuration
    */
-  virtual void writeToConfig(ISettings* config) const;
+  virtual void writeToConfig(ISettings* config) const override;
 
   /**
    * Read persisted configuration.
    *
    * @param config configuration
    */
-  virtual void readFromConfig(ISettings* config);
+  virtual void readFromConfig(ISettings* config) override;
 
   /** Get destination tag. */
   Frame::TagVersion numberTracksDestination() const { return m_numberTracksDst; }
@@ -136,5 +139,3 @@ private:
   /** Index in configuration storage */
   static int s_index;
 };
-
-#endif
