@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 16 Sep 2009
  *
- * Copyright (C) 2009-2013  Urs Fleisch
+ * Copyright (C) 2009-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,11 +24,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef PLAYLISTCONFIG_H
-#define PLAYLISTCONFIG_H
+#pragma once
 
 #include <QString>
-#include "config.h"
 #include "generalconfig.h"
 #include "kid3api.h"
 
@@ -38,25 +36,34 @@
 class KID3_CORE_EXPORT PlaylistConfig : public StoredConfig<PlaylistConfig> {
   Q_OBJECT
   /** Playlist location */
-  Q_PROPERTY(int location READ location WRITE setLocationInt NOTIFY locationChanged)
+  Q_PROPERTY(int location READ location WRITE setLocationInt
+             NOTIFY locationChanged)
   /** Playlist format */
   Q_PROPERTY(int format READ format WRITE setFormatInt NOTIFY formatChanged)
   /** Playlist file name format */
-  Q_PROPERTY(QString fileNameFormat READ fileNameFormat WRITE setFileNameFormat NOTIFY fileNameFormatChanged)
+  Q_PROPERTY(QString fileNameFormat READ fileNameFormat WRITE setFileNameFormat
+             NOTIFY fileNameFormatChanged)
   /** Tag field used for sorting */
-  Q_PROPERTY(QString sortTagField READ sortTagField WRITE setSortTagField NOTIFY sortTagFieldChanged)
+  Q_PROPERTY(QString sortTagField READ sortTagField WRITE setSortTagField
+             NOTIFY sortTagFieldChanged)
   /** Format for additional information */
-  Q_PROPERTY(QString infoFormat READ infoFormat WRITE setInfoFormat NOTIFY infoFormatChanged)
+  Q_PROPERTY(QString infoFormat READ infoFormat WRITE setInfoFormat
+             NOTIFY infoFormatChanged)
   /** Use file name format if true, else directory name */
-  Q_PROPERTY(bool useFileNameFormat READ useFileNameFormat WRITE setUseFileNameFormat NOTIFY useFileNameFormatChanged)
+  Q_PROPERTY(bool useFileNameFormat READ useFileNameFormat
+             WRITE setUseFileNameFormat NOTIFY useFileNameFormatChanged)
   /** Include only selected files if true, else all files */
-  Q_PROPERTY(bool onlySelectedFiles READ onlySelectedFiles WRITE setOnlySelectedFiles NOTIFY onlySelectedFilesChanged)
+  Q_PROPERTY(bool onlySelectedFiles READ onlySelectedFiles
+             WRITE setOnlySelectedFiles NOTIFY onlySelectedFilesChanged)
   /** Sort by tag field if true, else file name */
-  Q_PROPERTY(bool useSortTagField READ useSortTagField WRITE setUseSortTagField NOTIFY useSortTagFieldChanged)
+  Q_PROPERTY(bool useSortTagField READ useSortTagField WRITE setUseSortTagField
+             NOTIFY useSortTagFieldChanged)
   /** Use full path for files in playlist if true, else relative path */
-  Q_PROPERTY(bool useFullPath READ useFullPath WRITE setUseFullPath NOTIFY useFullPathChanged)
+  Q_PROPERTY(bool useFullPath READ useFullPath WRITE setUseFullPath
+             NOTIFY useFullPathChanged)
   /** Write info format, else only list of files */
-  Q_PROPERTY(bool writeInfo READ writeInfo WRITE setWriteInfo NOTIFY writeInfoChanged)
+  Q_PROPERTY(bool writeInfo READ writeInfo WRITE setWriteInfo
+             NOTIFY writeInfoChanged)
   Q_ENUMS(PlaylistFormat)
   Q_ENUMS(PlaylistLocation)
 public:
@@ -83,24 +90,37 @@ public:
    */
   explicit PlaylistConfig();
 
+  /**
+   * Copy constructor.
+   * @param other instance to be copied
+   */
+  PlaylistConfig(const PlaylistConfig& other);
+
   /**
    * Destructor.
    */
-  virtual ~PlaylistConfig();
+  virtual ~PlaylistConfig() override = default;
+
+  /**
+   * Assignment operator.
+   * @param other instance to be copied
+   * @return reference to this instance.
+   */
+  PlaylistConfig& operator=(const PlaylistConfig& other);
 
   /**
    * Persist configuration.
    *
    * @param config KDE configuration
    */
-  virtual void writeToConfig(ISettings* config) const;
+  virtual void writeToConfig(ISettings* config) const override;
 
   /**
    * Read persisted configuration.
    *
    * @param config KDE configuration
    */
-  virtual void readFromConfig(ISettings* config);
+  virtual void readFromConfig(ISettings* config) override;
 
   /** Get playlist location. */
   PlaylistLocation location() const { return m_location; }
@@ -162,12 +182,27 @@ public:
   /** Set if info format is written. */
   void setWriteInfo(bool writeInfo);
 
+  /**
+   * Get file extension for playlist format.
+   * @return ".m3u", ".pls" or ".xspf".
+   */
+  QString fileExtensionForFormat() const;
+
+  /**
+   * Get playlist format from file extension.
+   * @param path file path or name ending with extension
+   * @param ok if set true is returned here if @a path has a playlist extension
+   * @return playlist format.
+   */
+  static PlaylistFormat formatFromFileExtension(const QString& path,
+                                                bool* ok = nullptr);
+
 signals:
   /** Emitted when @a location changed. */
-  void locationChanged(PlaylistLocation location);
+  void locationChanged(PlaylistConfig::PlaylistLocation location);
 
   /** Emitted when @a format changed. */
-  void formatChanged(PlaylistFormat format);
+  void formatChanged(PlaylistConfig::PlaylistFormat format);
 
   /** Emitted when @a fileNameFormat changed. */
   void fileNameFormatChanged(const QString& fileNameFormat);
@@ -218,5 +253,3 @@ private:
   /** Index in configuration storage */
   static int s_index;
 };
-
-#endif // PLAYLISTCONFIG_H
