@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 30 Dec 2008
  *
- * Copyright (C) 2008-2017  Urs Fleisch
+ * Copyright (C) 2008-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -29,6 +29,8 @@
 #include <QNetworkRequest>
 #include <QNetworkProxy>
 #include <QByteArray>
+#include <QTimer>
+#include <QDateTime>
 #include "networkconfig.h"
 
 
@@ -65,13 +67,13 @@ static struct MinimumRequestIntervalInitializer {
  *
  * @param netMgr  network access manager
  */
-HttpClient::HttpClient(QNetworkAccessManager* netMgr) :
-  QObject(netMgr), m_netMgr(netMgr), m_rcvBodyLen(0),
-  m_requestTimer(new QTimer(this))
+HttpClient::HttpClient(QNetworkAccessManager* netMgr)
+  : QObject(netMgr), m_netMgr(netMgr), m_rcvBodyLen(0),
+    m_requestTimer(new QTimer(this))
 {
   setObjectName(QLatin1String("HttpClient"));
   m_requestTimer->setSingleShot(true);
-  connect(m_requestTimer, SIGNAL(timeout()), this, SLOT(delayedSendRequest()));
+  connect(m_requestTimer, &QTimer::timeout, this, &HttpClient::delayedSendRequest);
 }
 
 /**
@@ -94,7 +96,7 @@ HttpClient::~HttpClient()
  */
 void HttpClient::networkReplyFinished()
 {
-  if (QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender())) {
+  if (auto reply = qobject_cast<QNetworkReply*>(sender())) {
     QByteArray data(reply->readAll());
     m_rcvBodyType = reply->header(QNetworkRequest::ContentTypeHeader).toString();
     m_rcvBodyLen = reply->header(QNetworkRequest::ContentLengthHeader).toUInt();
@@ -117,12 +119,14 @@ void HttpClient::networkReplyFinished()
           QNetworkRequest request(redirectUrl);
           reply = m_netMgr->get(request);
           m_reply = reply;
-          connect(reply, SIGNAL(finished()),
-                  this, SLOT(networkReplyFinished()));
-          connect(reply, SIGNAL(downloadProgress(qint64,qint64)),
-                  this, SLOT(networkReplyProgress(qint64,qint64)));
-          connect(reply, SIGNAL(error(QNetworkReply::NetworkError)),
-                  this, SLOT(networkReplyError(QNetworkReply::NetworkError)));
+          connect(reply, &QNetworkReply::finished,
+                  this, &HttpClient::networkReplyFinished);
+          connect(reply, &QNetworkReply::downloadProgress,
+                  this, &HttpClient::networkReplyProgress);
+          connect(reply,
+                  static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(
+                    &QNetworkReply::error),
+                  this, &HttpClient::networkReplyError);
           return;
         }
       }
@@ -151,7 +155,7 @@ void HttpClient::networkReplyProgress(qint64 received, qint64 total)
  */
 void HttpClient::networkReplyError(QNetworkReply::NetworkError)
 {
-  if (QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender())) {
+  if (auto reply = qobject_cast<QNetworkReply*>(sender())) {
     emitProgress(reply->errorString(), -1, -1);
   }
 }
@@ -200,20 +204,19 @@ void HttpClient::sendRequest(const QUrl& url, const RawHeaderMap& headers)
                                    username, password));
 
   QNetworkRequest request(url);
-  for (RawHeaderMap::const_iterator it =
-         headers.constBegin();
-       it != headers.constEnd();
-       ++it) {
+  for (auto it = headers.constBegin(); it != headers.constEnd(); ++it) {
     request.setRawHeader(it.key(), it.value());
   }
   QNetworkReply* reply = m_netMgr->get(request);
   m_reply = reply;
-  connect(reply, SIGNAL(finished()),
-          this, SLOT(networkReplyFinished()));
-  connect(reply, SIGNAL(downloadProgress(qint64,qint64)),
-          this, SLOT(networkReplyProgress(qint64,qint64)));
-  connect(reply, SIGNAL(error(QNetworkReply::NetworkError)),
-          this, SLOT(networkReplyError(QNetworkReply::NetworkError)));
+  connect(reply, &QNetworkReply::finished,
+          this, &HttpClient::networkReplyFinished);
+  connect(reply, &QNetworkReply::downloadProgress,
+          this, &HttpClient::networkReplyProgress);
+  connect(reply,
+          static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(
+            &QNetworkReply::error),
+          this, &HttpClient::networkReplyError);
   s_lastRequestTime[host] = now;
   emitProgress(tr("Request sent..."), 0, 0);
 }
@@ -234,11 +237,7 @@ void HttpClient::sendRequest(const QString& server, const QString& path,
     host.chop(3);
   }
   QUrl url;
-#if QT_VERSION >= 0x050000
   url.setUrl(scheme + QLatin1String("://") + host + path);
-#else
-  url.setEncodedUrl((scheme + QLatin1String("://") + host + path).toAscii());
-#endif
   sendRequest(url, headers);
 }
 
@@ -286,7 +285,7 @@ void HttpClient::splitNamePort(const QString& namePort,
   int colPos = namePort.lastIndexOf(QLatin1Char(':'));
   if (colPos >= 0) {
     bool ok;
-    port = namePort.mid(colPos + 1).toInt(&ok);
+    port = namePort.midRef(colPos + 1).toInt(&ok);
     if (!ok) port = 80;
     name = namePort.left(colPos);
   } else {
