@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 13 Mar 2011
  *
- * Copyright (C) 2005-2017  Urs Fleisch
+ * Copyright (C) 2005-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -25,24 +25,18 @@
  */
 
 #include "configtablemodel.h"
+#include "modelsectionresizemode.h"
 
 /**
  * Constructor.
  * @param parent parent widget
  */
-ConfigTableModel::ConfigTableModel(QObject* parent) :
-  QAbstractTableModel(parent)
+ConfigTableModel::ConfigTableModel(QObject* parent)
+  : QAbstractTableModel(parent)
 {
   setObjectName(QLatin1String("ConfigTableModel"));
 }
 
-/**
- * Destructor.
- */
-ConfigTableModel::~ConfigTableModel()
-{
-}
-
 /**
  * Get item flags for index.
  * @param index model index
@@ -92,7 +86,7 @@ bool ConfigTableModel::setData(const QModelIndex& index,
       index.row() < 0 || index.row() >= m_keyValues.size() ||
       index.column() < 0 || index.column() >= 2)
     return false;
-  QPair<QString, QString>& keyValue = m_keyValues[index.row()];
+  QPair<QString, QString>& keyValue = m_keyValues[index.row()]; // clazy:exclude=detaching-member
   if (index.column() == 0) {
     keyValue.first = value.toString();
   } else {
@@ -185,11 +179,10 @@ bool ConfigTableModel::removeRows(int row, int count,
  * Get the resize modes to be used for the columns.
  * @return list of resize modes for the columns
  */
-QList<QHeaderView::ResizeMode>
+QList<ModelSectionResizeMode>
     ConfigTableModel::getHorizontalResizeModes() const
 {
-  return QList<QHeaderView::ResizeMode>()
-      << QHeaderView::Stretch << QHeaderView::Stretch;
+  return {ModelSectionResizeMode::Stretch, ModelSectionResizeMode::Stretch};
 }
 
 /**
@@ -206,36 +199,23 @@ void ConfigTableModel::setLabels(const QStringList& labels)
 /**
  * Set the model from a map.
  *
- * @param map map with keys and values
+ * @param map list with keys and values
  */
-void ConfigTableModel::setMap(const QMap<QString, QString>& map)
+void ConfigTableModel::setMap(const QList<QPair<QString, QString>>& map)
 {
   beginResetModel();
-  m_keyValues.clear();
-  for (QMap<QString, QString>::const_iterator it = map.constBegin();
-      it != map.constEnd();
-       ++it) {
-    m_keyValues.append(qMakePair(it.key(), it.value()));
-  }
+  m_keyValues = map;
   // make sure that at least one line is in the table
   if (m_keyValues.isEmpty())
-    m_keyValues.append(qMakePair(QString(), QString()));
+    m_keyValues.append({QString(), QString()});
   endResetModel();
 }
 
 /**
  * Get map from the model.
- * @return map with keys and values
+ * @return list with keys and values
  */
-QMap<QString, QString> ConfigTableModel::getMap() const
+QList<QPair<QString, QString>> ConfigTableModel::getMap() const
 {
-  QMap<QString, QString> map;
-  for (QList<QPair<QString, QString> >::const_iterator it = m_keyValues.constBegin();
-      it != m_keyValues.constEnd();
-      ++it) {
-    if (!it->first.isEmpty()) {
-      map.insert(it->first, it->second);
-    }
-  }
-  return map;
+  return m_keyValues;
 }
