@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 19-Mar-2011
  *
- * Copyright (C) 2011-2014  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -25,8 +25,8 @@
  */
 
 #include "dirproxymodel.h"
-#include <QFileSystemModel>
 #include <QDateTime>
+#include "filesystemmodel.h"
 
 /**
  * Constructor.
@@ -38,6 +38,17 @@ DirProxyModel::DirProxyModel(QObject* parent) : QSortFilterProxyModel(parent)
   setObjectName(QLatin1String("DirProxyModel"));
 }
 
+/**
+ * Get item flags.
+ * @param index index of item
+ * @return default flags without editable.
+ */
+Qt::ItemFlags DirProxyModel::flags(const QModelIndex& index) const
+{
+  // Prevent inplace editing (i.e. renaming) of directories.
+  return QSortFilterProxyModel::flags(index) & ~Qt::ItemIsEditable;
+}
+
 /**
  * Check if row should be included in model.
  *
@@ -48,7 +59,7 @@ DirProxyModel::DirProxyModel(QObject* parent) : QSortFilterProxyModel(parent)
  */
 bool DirProxyModel::filterAcceptsRow(int srcRow, const QModelIndex& srcParent) const
 {
-  QFileSystemModel* srcModel = qobject_cast<QFileSystemModel*>(sourceModel());
+  auto srcModel = qobject_cast<FileSystemModel*>(sourceModel());
   if (srcModel) {
     return srcModel->isDir(srcModel->index(srcRow, 0, srcParent));
   }
@@ -81,12 +92,12 @@ bool DirProxyModel::lessThan(const QModelIndex& left,
     return !orderIsAscending;
   }
 
-  // The data() in QFileSystemModel are String QVariants, therefore
+  // The data() in FileSystemModel are String QVariants, therefore
   // QSortFilterProxyModel::lessThan() is of no use here, custom sorting
   // has to be used.
-  Q_ASSERT_X(sourceModel()->metaObject() == &QFileSystemModel::staticMetaObject,
-             "lessThan", "source model must be QFileSystemModel");
-  QFileSystemModel* fsModel = static_cast<QFileSystemModel*>(sourceModel());
+  Q_ASSERT_X(sourceModel()->metaObject() == &FileSystemModel::staticMetaObject,
+             "lessThan", "source model must be FileSystemModel");
+  auto fsModel = static_cast<FileSystemModel*>(sourceModel());
   switch (sortColumn()) {
   case 0:
     return left.data().toString().compare(right.data().toString()) < 0;
@@ -101,12 +112,3 @@ bool DirProxyModel::lessThan(const QModelIndex& left,
            sortColumn());
   return QSortFilterProxyModel::lessThan(left, right);
 }
-
-/**
- * Reset the model.
- */
-void DirProxyModel::resetModel()
-{
-  beginResetModel();
-  endResetModel();
-}
