@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 22 Feb 2007
  *
- * Copyright (C) 2007  Urs Fleisch
+ * Copyright (C) 2007-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,18 +24,15 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef EXTERNALPROCESS_H
-#define EXTERNALPROCESS_H
+#pragma once
 
-#include <QDialog>
-#include <QTextEdit>
+#include <QObject>
 #include "kid3api.h"
 
 class QProcess;
 class QString;
 class QStringList;
 class Kid3Application;
-class TaggedFile;
 
 /**
  * Handler for external process.
@@ -44,34 +41,30 @@ class KID3_CORE_EXPORT ExternalProcess : public QObject {
   Q_OBJECT
 public:
   /**
-   * Dialog to show output from external process.
+   * Interface for viewer to show output from external process.
    */
-  class OutputViewer : public QDialog {
+  class KID3_CORE_EXPORT IOutputViewer {
   public:
-    /**
-     * Constructor.
-     *
-     * @param parent parent widget
-     */
-    explicit OutputViewer(QWidget* parent);
-
     /**
      * Destructor.
      */
-    virtual ~OutputViewer();
+    virtual ~IOutputViewer() = 0;
+
+    /**
+     * Set caption.
+     * @param title caption
+     */
+    virtual void setCaption(const QString& title) = 0;
 
     /**
      * Append text.
      */
-    void append(const QString& text);
+    virtual void append(const QString& text) = 0;
 
     /**
      * Scroll text to bottom.
      */
-    void scrollToBottom();
-
-  private:
-    QTextEdit* m_textEdit;
+    virtual void scrollToBottom() = 0;
   };
 
 
@@ -81,23 +74,35 @@ public:
    * @param app application context
    * @param parent parent object
    */
-  explicit ExternalProcess(Kid3Application* app, QWidget* parent = 0);
+  explicit ExternalProcess(Kid3Application* app, QObject* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~ExternalProcess();
+  virtual ~ExternalProcess() override;
+
+  /**
+   * Get output viewer.
+   * @return output viewer, default is null.
+   */
+  IOutputViewer* outputViewer() const { return m_outputViewer; }
+
+  /**
+   * Set output viewer.
+   * @param viewer output viewer to be used
+   */
+  void setOutputViewer(IOutputViewer* viewer) { m_outputViewer = viewer; }
 
   /**
    * Launch a command.
    *
    * @param name       display name
    * @param args       command and arguments
-   * @param confirm    true if confirmation required
    * @param showOutput true to show output of process
+   * @return false if process could not be executed.
    */
-  void launchCommand(const QString& name, const QStringList& args,
-                     bool confirm = false, bool showOutput = false);
+  bool launchCommand(const QString& name, const QStringList& args,
+                     bool showOutput = false);
 
 private slots:
   /**
@@ -113,9 +118,6 @@ private slots:
 
 private:
   Kid3Application* m_app;
-  QWidget* m_parent;
   QProcess* m_process;
-  OutputViewer* m_outputViewer;
+  IOutputViewer* m_outputViewer;
 };
-
-#endif // EXTERNALPROCESS_H
