@@ -27,7 +27,7 @@
 #include "fileproxymodel.h"
 #include <QTimer>
 #include "filesystemmodel.h"
-#include "taggedfileiconprovider.h"
+#include "coretaggedfileiconprovider.h"
 #include "itaggedfilefactory.h"
 #include "tagconfig.h"
 #include "saferename.h"
@@ -66,12 +66,15 @@ QHash<int,QByteArray> getRoleHash()
 /**
  * Constructor.
  *
+ * @param iconProvider icon provider
  * @param parent parent object
  */
-FileProxyModel::FileProxyModel(QObject* parent) : QSortFilterProxyModel(parent),
-  m_iconProvider(new TaggedFileIconProvider), m_fsModel(nullptr),
-  m_loadTimer(new QTimer(this)), m_sortTimer(new QTimer(this)),
-  m_numModifiedFiles(0), m_isLoading(false)
+FileProxyModel::FileProxyModel(CoreTaggedFileIconProvider* iconProvider,
+                               QObject* parent)
+  : QSortFilterProxyModel(parent),
+    m_iconProvider(iconProvider), m_fsModel(nullptr),
+    m_loadTimer(new QTimer(this)), m_sortTimer(new QTimer(this)),
+    m_numModifiedFiles(0), m_isLoading(false)
 {
   setObjectName(QLatin1String("FileProxyModel"));
   connect(this, &QAbstractItemModel::rowsInserted,
@@ -317,8 +320,8 @@ QVariant FileProxyModel::data(const QModelIndex& index, int role) const
     } else if (role == Qt::BackgroundRole && index.column() == 0) {
       TaggedFile* taggedFile = m_taggedFiles.value(index, nullptr);
       if (taggedFile) {
-        QColor color = m_iconProvider->backgroundForTaggedFile(taggedFile);
-        if (color.isValid())
+        QVariant color = m_iconProvider->backgroundForTaggedFile(taggedFile);
+        if (!color.isNull())
           return color;
       }
     } else if (role == IconIdRole && index.column() == 0) {
@@ -401,6 +404,33 @@ void FileProxyModel::emitSortingFinished()
   emit sortingFinished();
 }
 
+/**
+ * Count items in model.
+ * @param rootIndex index of root item
+ * @param folderCount the folder count is returned here
+ * @param fileCount the file count is returned here
+ */
+void FileProxyModel::countItems(const QModelIndex& rootIndex,
+                                int& folderCount, int& fileCount)
+{
+  folderCount = 0;
+  fileCount = 0;
+  QModelIndexList todo;
+  todo.append(rootIndex);
+  while (!todo.isEmpty()) {
+    QModelIndex parent = todo.takeFirst();
+    for (int row = 0, numRows = rowCount(parent); row < numRows; ++row) {
+      QModelIndex idx = index(row, 0, parent);
+      if (!hasChildren(idx)) {
+        ++fileCount;
+      } else {
+        ++folderCount;
+        todo.append(idx);
+      }
+    }
+  }
+}
+
 /**
  * Called when loading the directory starts.
  */
@@ -441,7 +471,7 @@ void FileProxyModel::fetchMore(const QModelIndex& parent)
  *
  * This method will directly call FileSystemModel::sort() on the
  * sourceModel() to take advantage of that specialized behavior. This
- * will change the order in the souce model.
+ * will change the order in the source model.
  *
  * @param column column to sort
  * @param order ascending or descending order
@@ -941,7 +971,7 @@ void FileProxyModel::notifyModificationChanged(const QModelIndex& index,
 
 /**
  * Called from tagged file to notify changes in extra model data, e.g. the
- * information on which the TaggedFileIconProvider depends.
+ * information on which the CoreTaggedFileIconProvider depends.
  * @param index model index
  */
 void FileProxyModel::notifyModelDataChanged(const QModelIndex& index)
