@@ -38,7 +38,7 @@
 class QTimer;
 class QFileInfo;
 class FileSystemModel;
-class TaggedFileIconProvider;
+class CoreTaggedFileIconProvider;
 class ITaggedFileFactory;
 
 /**
@@ -58,9 +58,11 @@ public:
   /**
    * Constructor.
    *
+   * @param iconProvider icon provider
    * @param parent parent object
    */
-  explicit FileProxyModel(QObject* parent = nullptr);
+  explicit FileProxyModel(CoreTaggedFileIconProvider* iconProvider,
+                          QObject* parent = nullptr);
 
   /**
    * Destructor.
@@ -118,7 +120,7 @@ public:
    *
    * This method will directly call FileSystemModel::sort() on the
    * sourceModel() to take advantage of that specialized behavior. This
-   * will change the order in the souce model.
+   * will change the order in the source model.
    *
    * @param column column to sort
    * @param order ascending or descending order
@@ -231,6 +233,15 @@ public:
 
   using QSortFilterProxyModel::index;
 
+  /**
+   * Count items in model.
+   * @param rootIndex index of root item
+   * @param folderCount the folder count is returned here
+   * @param fileCount the file count is returned here
+   */
+  void countItems(const QModelIndex& rootIndex,
+                  int& folderCount, int& fileCount);
+
   /**
    * Called from tagged file to notify modification state changes.
    * @param index model index
@@ -240,7 +251,7 @@ public:
 
   /**
    * Called from tagged file to notify changes in extra model data, e.g. the
-   * information on which the TaggedFileIconProvider depends.
+   * information on which the CoreTaggedFileIconProvider depends.
    * @param index model index
    */
   void notifyModelDataChanged(const QModelIndex& index);
@@ -265,7 +276,7 @@ public:
    * Get icon provider.
    * @return icon provider.
    */
-  TaggedFileIconProvider* getIconProvider() const { return m_iconProvider.data(); }
+  CoreTaggedFileIconProvider* getIconProvider() const { return m_iconProvider.data(); }
 
   /**
    * Access to tagged file factories.
@@ -509,7 +520,7 @@ private:
   QPersistentModelIndex m_exclusiveDraggableIndex;
   QList<QRegExp> m_includeFolderFilters;
   QList<QRegExp> m_excludeFolderFilters;
-  QScopedPointer<TaggedFileIconProvider> m_iconProvider;
+  QScopedPointer<CoreTaggedFileIconProvider> m_iconProvider;
   FileSystemModel* m_fsModel;
   QTimer* m_loadTimer;
   QTimer* m_sortTimer;
