@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 20 Sep 2014
  *
- * Copyright (C) 2014  Urs Fleisch
+ * Copyright (C) 2014-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef FRAMEEDITOROBJECT_H
-#define FRAMEEDITOROBJECT_H
+#pragma once
 
 #include <QObject>
 #include <QMap>
@@ -50,12 +49,12 @@ public:
    * Constructor.
    * @param parent parent object
    */
-  explicit FrameEditorObject(QObject* parent = 0);
+  explicit FrameEditorObject(QObject* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~FrameEditorObject();
+  virtual ~FrameEditorObject() override = default;
 
   // IFrameEditor implementation
 
@@ -69,7 +68,7 @@ public:
    * @param taggedFile tagged file where frame has to be set
    */
   virtual void editFrameOfTaggedFile(const Frame* frame,
-                                     TaggedFile* taggedFile);
+                                     TaggedFile* taggedFile) override;
 
   /**
    * Let user select a frame type.
@@ -79,16 +78,29 @@ public:
    * @param frame is filled with the selected frame
    * @param taggedFile tagged file for which frame has to be selected
    */
-  virtual void selectFrame(Frame* frame, const TaggedFile* taggedFile);
+  virtual void selectFrame(Frame* frame, const TaggedFile* taggedFile) override;
 
   /**
    * Return object which emits frameSelected(), frameEdited() signals.
    *
    * @return object which emits signals.
    */
-  virtual QObject* qobject();
+  virtual QObject* qobject() override;
+
+  /**
+   * Get the tag number of the edited frame.
+   * @return tag number, default is Frame::Tag_2.
+   */
+  virtual Frame::TagNumber tagNumber() const override { return m_tagNr; }
+
+  /**
+   * Set the tag number of the edited frame.
+   * @param tagNr tag number
+   */
+  virtual void setTagNumber(Frame::TagNumber tagNr) override { m_tagNr = tagNr; }
 
   // End of IFrameEditor implementation
+
 public slots:
   /**
    * Called when the frame selection dialog is closed.
@@ -113,15 +125,17 @@ signals:
 
   /**
    * Emitted when the dialog to add and edit a frame is closed.
+   * @param tagNr tag number
    * @param frame edited frame if dialog was accepted, else 0
    */
-  void frameEdited(const Frame* frame);
+  void frameEdited(Frame::TagNumber tagNr, const Frame* frame);
 
   /**
    * Emitted when the dialog to select a frame is closed.
+   * @param tagNr tag number
    * @param frame selected frame if dialog was accepted, else 0
    */
-  void frameSelected(const Frame* frame);
+  void frameSelected(Frame::TagNumber tagNr, const Frame* frame);
 
   // End of IFrameEditor implementation
 
@@ -148,6 +162,5 @@ private:
   FrameObjectModel* m_frameObjectModel;
   Frame m_editFrame;
   QMap<QString, QString> m_displayNameMap;
+  Frame::TagNumber m_tagNr;
 };
-
-#endif // FRAMEEDITOROBJECT_H
