@@ -25,10 +25,8 @@
  */
 
 #include "frametablemodel.h"
-#include <QGuiApplication>
-#include <QBrush>
-#include <QPalette>
 #include <algorithm>
+#include "coretaggedfileiconprovider.h"
 #include "fileconfig.h"
 #include "pictureframe.h"
 #include "framenotice.h"
@@ -57,12 +55,13 @@ QHash<int,QByteArray> getRoleHash()
 /**
  * Constructor.
  * @param id3v1  true if model for ID3v1 frames
+ * @param colorProvider colorProvider
  * @param parent parent widget
  */
-FrameTableModel::FrameTableModel(bool id3v1, QObject* parent)
+FrameTableModel::FrameTableModel(
+    bool id3v1, CoreTaggedFileIconProvider* colorProvider, QObject* parent)
   : QAbstractTableModel(parent), m_markedRows(0), m_changedFrames(0),
-    m_id3v1(id3v1),
-    m_guiApp(qobject_cast<QGuiApplication*>(QCoreApplication::instance()) != nullptr)
+    m_colorProvider(colorProvider), m_id3v1(id3v1)
 {
   setObjectName(QLatin1String("FrameTableModel"));
 }
@@ -115,17 +114,55 @@ QVariant FrameTableModel::data(const QModelIndex& index, int role) const
   if (role == Qt::DisplayRole || role == Qt::EditRole) {
     if (index.column() == CI_Enable) {
       QString displayName = Frame::getDisplayName(it->getName());
-      if (it->getType() == Frame::FT_Picture &&
-          it->getValue() != Frame::differentRepresentation()) {
-        QVariant fieldValue = it->getFieldValue(Frame::ID_PictureType);
-        if (fieldValue.isValid()) {
-          auto pictureType =
-              static_cast<PictureFrame::PictureType>(fieldValue.toInt());
-          if (pictureType != PictureFrame::PT_Other) {
-            QString typeName = PictureFrame::getPictureTypeName(pictureType);
-            if (!typeName.isEmpty()) {
-              displayName += QLatin1String(": ");
-              displayName += typeName;
+      if (it->getValue() != Frame::differentRepresentation()) {
+        if (it->getType() == Frame::FT_Picture) {
+          QVariant fieldValue = it->getFieldValue(Frame::ID_PictureType);
+          if (fieldValue.isValid()) {
+            auto pictureType =
+                static_cast<PictureFrame::PictureType>(fieldValue.toInt());
+            if (pictureType != PictureFrame::PT_Other) {
+              QString typeName = PictureFrame::getPictureTypeName(pictureType);
+              if (!typeName.isEmpty()) {
+                displayName += QLatin1String(": ");
+                displayName += typeName;
+              }
+            }
+          }
+        } else if (it->getType() == Frame::FT_Other) {
+          if (it->getInternalName().startsWith(QLatin1String("RVA2"))) {
+            QVariant fieldValue = it->getFieldValue(Frame::ID_Id);
+            if (fieldValue.isValid()) {
+              auto identifier = fieldValue.toString();
+              if (!identifier.isEmpty()) {
+                displayName = tr("Volume");
+                displayName += QLatin1String(": ");
+                displayName += identifier;
+              }
+            }
+          } else if (it->getInternalName().startsWith(QLatin1String("UFID"))) {
+            QVariant fieldValue = it->getFieldValue(Frame::ID_Owner);
+            if (fieldValue.isValid()) {
+              auto owner = fieldValue.toString();
+              if (!owner.isEmpty()) {
+                // Shorten the owner so that it is visible in the frame type column.
+                // For example http://musicbrainz.org -> musicbrainz
+                //             http://www.cddb.com/id3/taginfo.html -> taginfo
+                //             http://www.id3.org/dummy/ufid.html -> ufid
+                int endPos = owner.lastIndexOf(QLatin1Char('.'));
+                if (endPos != -1) {
+                  int startPos = owner.lastIndexOf(QLatin1Char('.'), endPos - 1);
+                  int slashPos = owner.lastIndexOf(QLatin1Char('/'), endPos - 1);
+                  if (slashPos != -1 && slashPos > startPos) {
+                    startPos = slashPos;
+                  }
+                  if (startPos != -1) {
+                    owner = owner.mid(startPos + 1, endPos - startPos - 1);
+                  }
+                }
+                displayName = tr("File ID");
+                displayName += QLatin1String(": ");
+                displayName += owner;
+              }
             }
           }
         }
@@ -136,12 +173,14 @@ QVariant FrameTableModel::data(const QModelIndex& index, int role) const
   } else if (role == Qt::CheckStateRole && index.column() == CI_Enable) {
     return m_frameSelected.at(index.row()) ? Qt::Checked : Qt::Unchecked;
   } else if (role == Qt::BackgroundColorRole) {
-    if (index.column() == CI_Enable) {
-      return !isModified ? Qt::NoBrush
-                         : m_guiApp ? QGuiApplication::palette().mid()
-                                    : QBrush(Qt::gray);
-    } else if (index.column() == CI_Value) {
-      return isTruncated ? QBrush(Qt::red) : Qt::NoBrush;
+    if (m_colorProvider) {
+      if (index.column() == CI_Enable) {
+        return m_colorProvider->colorForContext(
+              isModified ? ColorContext::Marked : ColorContext::None);
+      } else if (index.column() == CI_Value) {
+        return m_colorProvider->colorForContext(
+              isTruncated ? ColorContext::Error : ColorContext::None);
+      }
     }
   } else if (role == Qt::ToolTipRole) {
     QString toolTip;
