@@ -67,8 +67,7 @@ class Kid3ApplicationTagContext;
 class IAbortable;
 class ICorePlatformTools;
 class IUserCommandProcessor;
-class AudioPlayer;
-class PixmapProvider;
+class ImageDataProvider;
 class FrameEditorObject;
 class FileFilter;
 
@@ -150,6 +149,12 @@ public:
   void activateDbusInterface();
 #endif
 
+  /**
+   * Get platform tools.
+   * @return platform tools.
+   */
+  ICorePlatformTools* getPlatformTools() { return m_platformTools; }
+
  /**
   * Get file system model.
   * @return file system model.
@@ -303,7 +308,7 @@ public:
    * hold a pointer must be deleted before deleteAudioPlayer() is called!
    * @return audio player.
    */
-  Q_INVOKABLE AudioPlayer* getAudioPlayer();
+  Q_INVOKABLE QObject* getAudioPlayer();
 
   /**
    * Delete audio player.
@@ -446,13 +451,25 @@ public:
    * @param source format to get source text from tags
    * @param extraction regular expression with frame names and captures to
    * extract from source text
-   *
-   * @return true if ok.
    */
   Q_INVOKABLE void importFromTags(Frame::TagVersion tagMask,
                                   const QString& source,
                                   const QString& extraction);
 
+  /**
+   * Import from tags on selected files.
+   *
+   * @param tagMask tag mask
+   * @param source format to get source text from tags
+   * @param extraction regular expression with frame names and captures to
+   * extract from source text
+   *
+   * @return extracted values for "%{__return}(.+)", empty if not used.
+   */
+  Q_INVOKABLE QStringList importFromTagsToSelection(Frame::TagVersion tagMask,
+                                                    const QString& source,
+                                                    const QString& extraction);
+
   /**
    * Export.
    *
@@ -666,13 +683,6 @@ public:
    */
   Q_INVOKABLE void setPictureData(const QByteArray& data);
 
-  /**
-   * Format a filename if format while editing is switched on.
-   *
-   * @param taggedFile file to modify
-   */
-  void formatFileNameIfEnabled(TaggedFile* taggedFile) const;
-
   /**
    * Format frames if format while editing is switched on.
    *
@@ -683,9 +693,9 @@ public:
   /**
    * Add picture on drop.
    *
-   * @param image dropped image.
+   * @param frame dropped picture frame
    */
-  void dropImage(const QImage& image);
+  void dropImage(Frame* frame);
 
   /**
    * Handle URL on drop.
@@ -827,7 +837,7 @@ public:
    * Set the image provider.
    * @param imageProvider image provider
    */
-  void setImageProvider(PixmapProvider* imageProvider);
+  void setImageProvider(ImageDataProvider* imageProvider);
 
   /**
    * Get the numbers of the selected rows in a list suitable for scripting.
@@ -1466,6 +1476,12 @@ private slots:
    */
   void updateCoverArtImageId();
 
+  /**
+   * Save config when suspended, check intents when activated.
+   * @param state application state
+   */
+  void onApplicationStateChanged(Qt::ApplicationState state);
+
 private:
   /**
    * Load and initialize plugins depending on configuration.
@@ -1551,7 +1567,7 @@ private:
   /** Batch importer */
   BatchImporter* m_batchImporter;
   /** Audio player */
-  AudioPlayer* m_player;
+  QObject* m_player;
 #ifdef HAVE_QTDBUS
   QString m_mprisServiceName;
 #endif
@@ -1608,7 +1624,7 @@ private:
   FrameEditorObject* m_frameEditor;
   IFrameEditor* m_storedFrameEditor;
   /* Support for image provider */
-  PixmapProvider* m_imageProvider;
+  ImageDataProvider* m_imageProvider;
   QString m_coverArtImageId;
 
 #ifdef Q_OS_ANDROID
