@@ -143,6 +143,24 @@ void ScriptInterface::importFromTags(int tagMask,
   m_app->importFromTags(Frame::tagVersionCast(tagMask), source, extraction);
 }
 
+/**
+ * Import from tags on selected files.
+ *
+ * @param tagMask tag mask
+ * @param source format to get source text from tags
+ * @param extraction regular expression with frame names and captures to
+ * extract from source text
+ *
+ * @return extracted values for "%{__return}(.+)", empty if not used.
+ */
+QStringList ScriptInterface::importFromTagsToSelection(int tagMask,
+                                                      const QString& source,
+                                                      const QString& extraction)
+{
+  return m_app->importFromTagsToSelection(Frame::tagVersionCast(tagMask),
+                                          source, extraction);
+}
+
 /**
  * Start an automatic batch import.
  *
