@@ -36,6 +36,7 @@
 #endif
 #include <sys/stat.h>
 #include "tagconfig.h"
+#include "formatconfig.h"
 #include "genres.h"
 #include "modeliterator.h"
 #include "saferename.h"
@@ -95,6 +96,19 @@ void TaggedFile::setFilename(const QString& fn)
   updateModifiedState();
 }
 
+/**
+ * Set file name and format it if format while editing is switched on.
+ *
+ * @param fn file name
+ */
+void TaggedFile::setFilenameFormattedIfEnabled(QString fn)
+{
+  if (FilenameFormatConfig::instance().formatWhileEditing()) {
+    FilenameFormatConfig::instance().formatString(fn);
+  }
+  setFilename(fn);
+}
+
 /**
  * Update the current filename after the file was renamed.
  */
@@ -304,7 +318,7 @@ void TaggedFile::updateModifiedState()
 
 /**
  * Notify model about changes in extra model data, e.g. the information on
- * which the TaggedFileIconProvider depends.
+ * which the CoreTaggedFileIconProvider depends.
  *
  * This method shall be called when such data changes, e.g. at the end of
  * readTags() implementations.
