@@ -94,6 +94,13 @@ public:
    */
   void setFilename(const QString& fn);
 
+  /**
+   * Set file name and format it if format while editing is switched on.
+   *
+   * @param fn file name
+   */
+  void setFilenameFormattedIfEnabled(QString fn);
+
   /**
    * Get file name.
    *
@@ -600,7 +607,7 @@ protected:
 
   /**
    * Notify model about changes in extra model data, e.g. the information on
-   * which the TaggedFileIconProvider depends.
+   * which the CoreTaggedFileIconProvider depends.
    *
    * This method shall be called when such data changes, e.g. at the end of
    * readTags() implementations.
