@@ -28,6 +28,7 @@
 #include <QString>
 #include <QUrl>
 #include <QDir>
+#include <QDateTime>
 #include <QCoreApplication>
 #include "fileproxymodel.h"
 
@@ -111,6 +112,17 @@ QString TrackDataFormatReplacer::getReplacement(const QString& code) const
         result = filename;
       } else if (name == QLatin1String("filepath")) {
         result = m_trackData.getAbsFilename();
+      } else if (name == QLatin1String("modificationdate")) {
+        return QFileInfo(m_trackData.getAbsFilename())
+            .lastModified().toString(Qt::ISODate);
+      } else if (name == QLatin1String("creationdate")) {
+#if QT_VERSION >= 0x050a00
+        return QFileInfo(m_trackData.getAbsFilename())
+            .birthTime().toString(Qt::ISODate);
+#else
+        return QFileInfo(m_trackData.getAbsFilename())
+            .created().toString(Qt::ISODate);
+#endif
       } else if (name == QLatin1String("url")) {
         QUrl url;
         url.setPath(m_trackData.getAbsFilename());
@@ -193,6 +205,18 @@ QString TrackDataFormatReplacer::getToolTip(bool onlyRows)
   str += QCoreApplication::translate("@default", absolutePathToFileStr);
   str += QLatin1String("</td></tr>\n");
 
+  str += QLatin1String("<tr><td></td><td>%{modificationdate}</td><td>");
+  const char* const modificationDateStr =
+      QT_TRANSLATE_NOOP("@default", "Modification date");
+  str += QCoreApplication::translate("@default", modificationDateStr);
+  str += QLatin1String("</td></tr>\n");
+
+  str += QLatin1String("<tr><td></td><td>%{creationdate}</td><td>");
+  const char* const creationDateStr =
+      QT_TRANSLATE_NOOP("@default", "Creation date");
+  str += QCoreApplication::translate("@default", creationDateStr);
+  str += QLatin1String("</td></tr>\n");
+
   str += QLatin1String("<tr><td>%u</td><td>%{url}</td><td>");
   str += QCoreApplication::translate("@default", "URL");
   str += QLatin1String("</td></tr>\n");
@@ -406,13 +430,7 @@ QString TrackData::formatString(const QString& format) const
 QString TrackData::formatFilenameFromTags(QString str, bool isDirname) const
 {
   if (!isDirname) {
-    // first remove directory part from str
-    const int sepPos = str.lastIndexOf(QLatin1Char('/'));
-    if (sepPos >= 0) {
-      str.remove(0, sepPos + 1);
-    }
-    // add extension to str
-    str += getFileExtension(true);
+    transformToFilename(str);
   }
 
   TrackDataFormatReplacer fmt(*this, str);
@@ -421,6 +439,22 @@ QString TrackData::formatFilenameFromTags(QString str, bool isDirname) const
   return fmt.getString();
 }
 
+/**
+ * Transform string to file name.
+ * The directory part is removed and a file extension added.
+ * @param str string to transform
+ */
+void TrackData::transformToFilename(QString& str) const
+{
+  // first remove directory part from str
+  const int sepPos = str.lastIndexOf(QLatin1Char('/'));
+  if (sepPos >= 0) {
+    str.remove(0, sepPos + 1);
+  }
+  // add extension to str
+  str += getFileExtension(true);
+}
+
 /**
  * Get help text for format codes supported by formatString().
  *
