@@ -52,6 +52,7 @@
 #include "networkconfig.h"
 #include "importconfig.h"
 #include "stringlistedit.h"
+#include "stringlisteditdialog.h"
 #include "configtable.h"
 #include "commandstablemodel.h"
 #include "checkablestringlistmodel.h"
@@ -74,13 +75,13 @@ QString folderPatternListToString(const QStringList& folders,
 {
   QStringList patterns;
   QChar sep = QLatin1Char(' ');
-  foreach (const QString& folder, folders) {
+  for (const QString& folder : folders) {
     QString pattern = folder.trimmed();
     if (!pattern.isEmpty()) {
       if (pattern.contains(QLatin1Char(' '))) {
         sep = QLatin1Char(';');
       }
-      patterns.append(pattern);
+      patterns.append(pattern); // clazy:exclude=reserve-candidates
     }
   }
   patterns.removeDuplicates();
@@ -109,10 +110,11 @@ QStringList folderPatternListFromString(const QString& patterns,
   QStringList folders;
   const QChar sep = patterns.contains(QLatin1Char(';'))
       ? QLatin1Char(';') : QLatin1Char(' ');
-  foreach (const QString& pattern, patterns.split(sep)) {
+  const auto patternList = patterns.split(sep);
+  for (const QString& pattern : patternList) {
     QString folder = pattern.trimmed();
     if (!folder.isEmpty()) {
-      folders.append(folder);
+      folders.append(folder); // clazy:exclude=reserve-candidates
     }
   }
 
@@ -127,32 +129,27 @@ QStringList folderPatternListFromString(const QString& patterns,
 ConfigDialogPages::ConfigDialogPages(IPlatformTools* platformTools,
                                      QObject* parent) : QObject(parent),
   m_platformTools(platformTools),
-  m_loadLastOpenedFileCheckBox(0), m_preserveTimeCheckBox(0),
-  m_markChangesCheckBox(0), m_coverFileNameLineEdit(0),
-  m_nameFilterComboBox(0), m_includeFoldersLineEdit(0),
-  m_excludeFoldersLineEdit(0), m_showHiddenFilesCheckBox(0),
-  m_fileTextEncodingComboBox(0),
-  m_markTruncationsCheckBox(0), m_textEncodingV1ComboBox(0),
-  m_totalNumTracksCheckBox(0), m_commentNameComboBox(0),
-  m_pictureNameComboBox(0), m_markOversizedPicturesCheckBox(0),
-  m_maximumPictureSizeSpinBox(0), m_genreNotNumericCheckBox(0),
-  m_lowercaseId3ChunkCheckBox(0), m_markStandardViolationsCheckBox(0),
-  m_textEncodingComboBox(0), m_id3v2VersionComboBox(0),
-  m_trackNumberDigitsSpinBox(0), m_fnFormatBox(0), m_tagFormatBox(0),
-  m_onlyCustomGenresCheckBox(0), m_genresEditModel(0),
-  m_quickAccessTagsModel(0), m_starRatingMappingsModel(0),
-  m_trackNameComboBox(0), m_playOnDoubleClickCheckBox(0),
-  m_commandsTable(0), m_commandsTableModel(0), m_browserLineEdit(0),
-  m_proxyCheckBox(0), m_proxyLineEdit(0), m_proxyAuthenticationCheckBox(0),
-  m_proxyUserNameLineEdit(0), m_proxyPasswordLineEdit(0),
-  m_enabledMetadataPluginsModel(0), m_enabledPluginsModel(0)
-{
-}
-
-/**
- * Destructor.
- */
-ConfigDialogPages::~ConfigDialogPages()
+  m_loadLastOpenedFileCheckBox(nullptr), m_preserveTimeCheckBox(nullptr),
+  m_markChangesCheckBox(nullptr), m_coverFileNameLineEdit(nullptr),
+  m_nameFilterComboBox(nullptr), m_includeFoldersLineEdit(nullptr),
+  m_excludeFoldersLineEdit(nullptr), m_showHiddenFilesCheckBox(nullptr),
+  m_fileTextEncodingComboBox(nullptr),
+  m_markTruncationsCheckBox(nullptr), m_textEncodingV1ComboBox(nullptr),
+  m_totalNumTracksCheckBox(nullptr), m_commentNameComboBox(nullptr),
+  m_pictureNameComboBox(nullptr), m_markOversizedPicturesCheckBox(nullptr),
+  m_maximumPictureSizeSpinBox(nullptr), m_genreNotNumericCheckBox(nullptr),
+  m_lowercaseId3ChunkCheckBox(nullptr),
+  m_markStandardViolationsCheckBox(nullptr), m_textEncodingComboBox(nullptr),
+  m_id3v2VersionComboBox(nullptr), m_trackNumberDigitsSpinBox(nullptr),
+  m_fnFormatBox(nullptr), m_tagFormatBox(nullptr),
+  m_onlyCustomGenresCheckBox(nullptr), m_genresEditModel(nullptr),
+  m_quickAccessTagsModel(nullptr), m_starRatingMappingsModel(nullptr),
+  m_trackNameComboBox(nullptr), m_playOnDoubleClickCheckBox(nullptr),
+  m_commandsTable(nullptr), m_commandsTableModel(nullptr),
+  m_browserLineEdit(nullptr), m_proxyCheckBox(nullptr),
+  m_proxyLineEdit(nullptr), m_proxyAuthenticationCheckBox(nullptr),
+  m_proxyUserNameLineEdit(nullptr), m_proxyPasswordLineEdit(nullptr),
+  m_enabledMetadataPluginsModel(nullptr), m_enabledPluginsModel(nullptr)
 {
 }
 
@@ -163,18 +160,20 @@ ConfigDialogPages::~ConfigDialogPages()
 QWidget* ConfigDialogPages::createTagsPage()
 {
   QWidget* tagsPage = new QWidget;
-  QVBoxLayout* vlayout = new QVBoxLayout(tagsPage);
+  auto vlayout = new QVBoxLayout(tagsPage);
 
   QWidget* tag1Page = new QWidget;
-  QVBoxLayout* tag1Layout = new QVBoxLayout(tag1Page);
+  auto tag1Layout = new QVBoxLayout(tag1Page);
   QGroupBox* v1GroupBox = new QGroupBox(tr("ID3v1"), tag1Page);
-  QGridLayout* v1GroupBoxLayout = new QGridLayout(v1GroupBox);
-  m_markTruncationsCheckBox = new QCheckBox(tr("&Mark truncated fields"), v1GroupBox);
+  auto v1GroupBoxLayout = new QGridLayout(v1GroupBox);
+  m_markTruncationsCheckBox = new QCheckBox(
+        tr("&Mark truncated fields"), v1GroupBox);
   v1GroupBoxLayout->addWidget(m_markTruncationsCheckBox, 0, 0, 1, 2);
   QLabel* textEncodingV1Label = new QLabel(tr("Text &encoding:"), v1GroupBox);
   m_textEncodingV1ComboBox = new QComboBox(v1GroupBox);
   m_textEncodingV1ComboBox->addItems(TagConfig::getTextCodecNames());
-  m_textEncodingV1ComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
+  m_textEncodingV1ComboBox->setSizePolicy(
+        QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
   textEncodingV1Label->setBuddy(m_textEncodingV1ComboBox);
   v1GroupBoxLayout->addWidget(textEncodingV1Label, 1, 0);
   v1GroupBoxLayout->addWidget(m_textEncodingV1ComboBox, 1, 1);
@@ -182,22 +181,28 @@ QWidget* ConfigDialogPages::createTagsPage()
   tag1Layout->addStretch();
 
   QWidget* tag2Page = new QWidget;
-  QHBoxLayout* tag2Layout = new QHBoxLayout(tag2Page);
-  QVBoxLayout* tag2LeftLayout = new QVBoxLayout;
+  auto tag2Layout = new QHBoxLayout(tag2Page);
+  auto tag2LeftLayout = new QVBoxLayout;
   QGroupBox* v2GroupBox = new QGroupBox(tr("ID3v2"), tag2Page);
-  QGridLayout* v2GroupBoxLayout = new QGridLayout(v2GroupBox);
-  m_totalNumTracksCheckBox = new QCheckBox(tr("Use &track/total number of tracks format"), v2GroupBox);
+  auto v2GroupBoxLayout = new QGridLayout(v2GroupBox);
+  m_totalNumTracksCheckBox = new QCheckBox(
+        tr("Use &track/total number of tracks format"), v2GroupBox);
   v2GroupBoxLayout->addWidget(m_totalNumTracksCheckBox, 0, 0, 1, 2);
-  QLabel* trackNumberDigitsLabel = new QLabel(tr("Track number &digits:"), v2GroupBox);
+  QLabel* trackNumberDigitsLabel = new QLabel(
+        tr("Track number &digits:"), v2GroupBox);
   m_trackNumberDigitsSpinBox = new QSpinBox(v2GroupBox);
   m_trackNumberDigitsSpinBox->setMaximum(5);
-  m_genreNotNumericCheckBox = new QCheckBox(tr("&Genre as text instead of numeric string"), v2GroupBox);
-  m_lowercaseId3ChunkCheckBox = new QCheckBox(tr("&WAV files with lowercase id3 chunk"), v2GroupBox);
-  m_markStandardViolationsCheckBox = new QCheckBox(tr("Mar&k standard violations"));
+  m_genreNotNumericCheckBox = new QCheckBox(
+        tr("&Genre as text instead of numeric string"), v2GroupBox);
+  m_lowercaseId3ChunkCheckBox = new QCheckBox(
+        tr("&WAV files with lowercase id3 chunk"), v2GroupBox);
+  m_markStandardViolationsCheckBox =
+      new QCheckBox(tr("Mar&k standard violations"));
   QLabel* textEncodingLabel = new QLabel(tr("Text &encoding:"), v2GroupBox);
   m_textEncodingComboBox = new QComboBox(v2GroupBox);
   m_textEncodingComboBox->addItems(TagConfig::getTextEncodingNames());
-  m_textEncodingComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
+  m_textEncodingComboBox->setSizePolicy(
+        QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
   textEncodingLabel->setBuddy(m_textEncodingComboBox);
   v2GroupBoxLayout->addWidget(m_genreNotNumericCheckBox, 1, 0, 1, 2);
   v2GroupBoxLayout->addWidget(m_lowercaseId3ChunkCheckBox, 2, 0, 1, 2);
@@ -211,13 +216,15 @@ QWidget* ConfigDialogPages::createTagsPage()
     textEncodingLabel->hide();
     m_textEncodingComboBox->hide();
   }
-  QLabel* id3v2VersionLabel = new QLabel(tr("&Version used for new tags:"), v2GroupBox);
+  QLabel* id3v2VersionLabel = new QLabel(tr("&Version used for new tags:"),
+                                         v2GroupBox);
   m_id3v2VersionComboBox = new QComboBox(v2GroupBox);
   if (tagCfg.taggedFileFeatures() & TaggedFile::TF_ID3v23)
     m_id3v2VersionComboBox->addItem(tr("ID3v2.3.0"), TagConfig::ID3v2_3_0);
   if (tagCfg.taggedFileFeatures() & TaggedFile::TF_ID3v24)
     m_id3v2VersionComboBox->addItem(tr("ID3v2.4.0"), TagConfig::ID3v2_4_0);
-  m_id3v2VersionComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
+  m_id3v2VersionComboBox->setSizePolicy(
+        QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
   id3v2VersionLabel->setBuddy(m_id3v2VersionComboBox);
   v2GroupBoxLayout->addWidget(id3v2VersionLabel, 5, 0);
   v2GroupBoxLayout->addWidget(m_id3v2VersionComboBox, 5, 1);
@@ -230,18 +237,22 @@ QWidget* ConfigDialogPages::createTagsPage()
   v2GroupBoxLayout->addWidget(m_trackNumberDigitsSpinBox, 6, 1);
   tag2LeftLayout->addWidget(v2GroupBox);
   QGroupBox* vorbisGroupBox = new QGroupBox(tr("Ogg/Vorbis"), tag2Page);
-  QLabel* commentNameLabel = new QLabel(tr("Co&mment field name:"), vorbisGroupBox);
+  QLabel* commentNameLabel = new QLabel(tr("Co&mment field name:"),
+                                        vorbisGroupBox);
   m_commentNameComboBox = new QComboBox(vorbisGroupBox);
-  QLabel* pictureNameLabel = new QLabel(tr("&Picture field name:"), vorbisGroupBox);
+  QLabel* pictureNameLabel = new QLabel(tr("&Picture field name:"),
+                                        vorbisGroupBox);
   m_pictureNameComboBox = new QComboBox(vorbisGroupBox);
   m_commentNameComboBox->setEditable(true);
   m_commentNameComboBox->addItems(TagConfig::getCommentNames());
-  m_commentNameComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
+  m_commentNameComboBox->setSizePolicy(
+        QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
   commentNameLabel->setBuddy(m_commentNameComboBox);
   m_pictureNameComboBox->addItems(TagConfig::getPictureNames());
-  m_pictureNameComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
+  m_pictureNameComboBox->setSizePolicy(
+        QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
   pictureNameLabel->setBuddy(m_pictureNameComboBox);
-  QGridLayout* vorbisGroupBoxLayout = new QGridLayout(vorbisGroupBox);
+  auto vorbisGroupBoxLayout = new QGridLayout(vorbisGroupBox);
   vorbisGroupBoxLayout->addWidget(commentNameLabel, 0, 0);
   vorbisGroupBoxLayout->addWidget(m_commentNameComboBox, 0, 1);
   vorbisGroupBoxLayout->addWidget(pictureNameLabel, 1, 0);
@@ -252,7 +263,7 @@ QWidget* ConfigDialogPages::createTagsPage()
     vorbisGroupBox->hide();
   }
   QGroupBox* pictureGroupBox = new QGroupBox(tr("Picture"), tag2Page);
-  QHBoxLayout* pictureGroupBoxLayout = new QHBoxLayout(pictureGroupBox);
+  auto pictureGroupBoxLayout = new QHBoxLayout(pictureGroupBox);
   m_markOversizedPicturesCheckBox =
       new QCheckBox(tr("Mark if &larger than (bytes):"));
   m_maximumPictureSizeSpinBox = new QSpinBox;
@@ -263,20 +274,21 @@ QWidget* ConfigDialogPages::createTagsPage()
   tag2LeftLayout->addStretch();
   tag2Layout->addLayout(tag2LeftLayout);
 
-  QVBoxLayout* tag2RightLayout = new QVBoxLayout;
+  auto tag2RightLayout = new QVBoxLayout;
   QGroupBox* genresGroupBox = new QGroupBox(tr("Custom &Genres"), tag2Page);
-  m_onlyCustomGenresCheckBox = new QCheckBox(tr("&Show only custom genres"), genresGroupBox);
+  m_onlyCustomGenresCheckBox = new QCheckBox(tr("&Show only custom genres"),
+                                             genresGroupBox);
   m_genresEditModel = new QStringListModel(genresGroupBox);
-  StringListEdit* genresEdit = new StringListEdit(m_genresEditModel, genresGroupBox);
-  QVBoxLayout* vbox = new QVBoxLayout;
+  auto genresEdit = new StringListEdit(m_genresEditModel, genresGroupBox);
+  auto vbox = new QVBoxLayout;
   vbox->addWidget(m_onlyCustomGenresCheckBox);
   vbox->addWidget(genresEdit);
   genresGroupBox->setLayout(vbox);
   tag2RightLayout->addWidget(genresGroupBox);
 
   QGroupBox* quickAccessTagsGroupBox = new QGroupBox(tr("&Quick Access Frames"));
-  QVBoxLayout* quickAccessTagsLayout = new QVBoxLayout(quickAccessTagsGroupBox);
-  QListView* quickAccessTagsListView = new QListView;
+  auto quickAccessTagsLayout = new QVBoxLayout(quickAccessTagsGroupBox);
+  auto quickAccessTagsListView = new QListView;
   m_quickAccessTagsModel = new QStandardItemModel(quickAccessTagsGroupBox);
   quickAccessTagsListView->setModel(m_quickAccessTagsModel);
   quickAccessTagsListView->setAcceptDrops(true);
@@ -294,15 +306,17 @@ QWidget* ConfigDialogPages::createTagsPage()
   tag2Layout->addLayout(tag2RightLayout);
 
   QWidget* tag3Page = new QWidget;
-  QVBoxLayout* tag3Layout = new QVBoxLayout(tag3Page);
+  auto tag3Layout = new QVBoxLayout(tag3Page);
   QGroupBox* riffGroupBox = new QGroupBox(tr("RIFF INFO"), tag3Page);
-  QLabel* trackNameLabel = new QLabel(tr("Track nu&mber field name:"), riffGroupBox);
+  QLabel* trackNameLabel = new QLabel(tr("Track nu&mber field name:"),
+                                      riffGroupBox);
   m_trackNameComboBox = new QComboBox(riffGroupBox);
   m_trackNameComboBox->setEditable(true);
   m_trackNameComboBox->addItems(TagConfig::getRiffTrackNames());
-  m_trackNameComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
+  m_trackNameComboBox->setSizePolicy(
+        QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
   trackNameLabel->setBuddy(m_trackNameComboBox);
-  QGridLayout* riffGroupBoxLayout = new QGridLayout(riffGroupBox);
+  auto riffGroupBoxLayout = new QGridLayout(riffGroupBox);
   riffGroupBoxLayout->addWidget(trackNameLabel, 0, 0);
   riffGroupBoxLayout->addWidget(m_trackNameComboBox, 0, 1);
   riffGroupBox->setLayout(riffGroupBoxLayout);
@@ -310,18 +324,18 @@ QWidget* ConfigDialogPages::createTagsPage()
   tag3Layout->addStretch();
 
   QWidget* tag1AndTag2Page = new QWidget;
-  QVBoxLayout* tag1AndTag2Layout = new QVBoxLayout(tag1AndTag2Page);
+  auto tag1AndTag2Layout = new QVBoxLayout(tag1AndTag2Page);
   QString tagFormatTitle(tr("&Tag Format"));
   m_tagFormatBox = new TagFormatBox(tagFormatTitle, tag1AndTag2Page);
   QGroupBox* ratingGroupBox = new QGroupBox(tr("Rating"), tag1AndTag2Page);
-  QVBoxLayout* ratingLayout = new QVBoxLayout(ratingGroupBox);
+  auto ratingLayout = new QVBoxLayout(ratingGroupBox);
   m_starRatingMappingsModel = new StarRatingMappingsModel(ratingGroupBox);
-  TableModelEdit* ratingEdit = new TableModelEdit(m_starRatingMappingsModel);
+  auto ratingEdit = new TableModelEdit(m_starRatingMappingsModel);
   ratingLayout->addWidget(ratingEdit);
   tag1AndTag2Layout->addWidget(m_tagFormatBox);
   tag1AndTag2Layout->addWidget(ratingGroupBox);
 
-  QTabWidget* tagsTabWidget = new QTabWidget;
+  auto tagsTabWidget = new QTabWidget;
   if (tagCfg.taggedFileFeatures() & TaggedFile::TF_ID3v11) {
     tagsTabWidget->addTab(tag1Page, tr("Tag &1"));
   }
@@ -340,27 +354,28 @@ QWidget* ConfigDialogPages::createTagsPage()
 QWidget* ConfigDialogPages::createFilesPage()
 {
   QWidget* filesPage = new QWidget;
-  QVBoxLayout* vlayout = new QVBoxLayout(filesPage);
-  QHBoxLayout* hlayout = new QHBoxLayout;
-  QVBoxLayout* leftLayout = new QVBoxLayout;
-  QVBoxLayout* rightLayout = new QVBoxLayout;
+  auto vlayout = new QVBoxLayout(filesPage);
+  auto hlayout = new QHBoxLayout;
+  auto leftLayout = new QVBoxLayout;
+  auto rightLayout = new QVBoxLayout;
 
   QGroupBox* startupGroupBox = new QGroupBox(tr("Startup"), filesPage);
   m_loadLastOpenedFileCheckBox = new QCheckBox(tr("&Load last-opened files"),
                                                startupGroupBox);
-  QVBoxLayout* startupLayout = new QVBoxLayout;
+  auto startupLayout = new QVBoxLayout;
   startupLayout->addWidget(m_loadLastOpenedFileCheckBox);
   startupGroupBox->setLayout(startupLayout);
   leftLayout->addWidget(startupGroupBox);
   QGroupBox* saveGroupBox = new QGroupBox(tr("Save"), filesPage);
-  m_preserveTimeCheckBox = new QCheckBox(tr("&Preserve file timestamp"), saveGroupBox);
+  m_preserveTimeCheckBox = new QCheckBox(tr("&Preserve file timestamp"),
+                                         saveGroupBox);
   m_markChangesCheckBox = new QCheckBox(tr("&Mark changes"), saveGroupBox);
   m_coverFileNameLineEdit = new QLineEdit(saveGroupBox);
   m_fileTextEncodingComboBox = new QComboBox(saveGroupBox);
   m_fileTextEncodingComboBox->addItems(FileConfig::getTextCodecNames());
   m_fileTextEncodingComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,
                                                         QSizePolicy::Minimum));
-  QFormLayout* formLayout = new QFormLayout;
+  auto formLayout = new QFormLayout;
   formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
   formLayout->addRow(m_preserveTimeCheckBox);
   formLayout->addRow(m_markChangesCheckBox);
@@ -376,20 +391,8 @@ QWidget* ConfigDialogPages::createFilesPage()
   m_nameFilterComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,
                                                   QSizePolicy::Minimum));
   QList<QPair<QString, QString> > filters = FileProxyModel::createNameFilters();
-  for (QList<QPair<QString, QString> >::const_iterator it = filters.constBegin();
-       it != filters.constEnd();
-       ++it) {
-    QString nameFilter = m_platformTools->fileDialogNameFilter(
-          QList<QPair<QString, QString> >() << *it);
-#if QT_VERSION < 0x050000
-    // Filters from the KDE 4 file dialog are not consistent, filter uses
-    // something like "*.mp3|MP3 (*.mp3)", but the current filter returns only
-    // something like "*.mp3".
-    int pipeIndex = nameFilter.indexOf(QLatin1Char('|'));
-    if (pipeIndex != -1) {
-      nameFilter = nameFilter.left(pipeIndex);
-    }
-#endif
+  for (auto it = filters.constBegin(); it != filters.constEnd(); ++it) {
+    QString nameFilter = m_platformTools->fileDialogNameFilter({*it});
     m_nameFilterComboBox->addItem(it->first, nameFilter);
   }
   nameFilterLabel->setBuddy(m_nameFilterComboBox);
@@ -403,7 +406,7 @@ QWidget* ConfigDialogPages::createFilesPage()
   excludeFoldersLabel->setBuddy(m_excludeFoldersLineEdit);
   m_showHiddenFilesCheckBox = new QCheckBox(tr("&Show hidden files"),
                                             fileListGroupBox);
-  QGridLayout* fileListGroupBoxLayout = new QGridLayout(fileListGroupBox);
+  auto fileListGroupBoxLayout = new QGridLayout(fileListGroupBox);
   fileListGroupBoxLayout->addWidget(nameFilterLabel, 0, 0);
   fileListGroupBoxLayout->addWidget(m_nameFilterComboBox, 0, 1);
   fileListGroupBoxLayout->addWidget(includeFoldersLabel, 1, 0);
@@ -412,6 +415,21 @@ QWidget* ConfigDialogPages::createFilesPage()
   fileListGroupBoxLayout->addWidget(m_excludeFoldersLineEdit, 2, 1);
   fileListGroupBoxLayout->addWidget(m_showHiddenFilesCheckBox, 3, 0, 1, 2);
   rightLayout->addWidget(fileListGroupBox);
+
+  auto formatGroupBox = new QGroupBox(tr("Format"), filesPage);
+  auto formatLayout = new QHBoxLayout(formatGroupBox);
+  auto editFormatsFromTagButton =
+          new QPushButton(tr("Filename from tag") + QLatin1String("..."));
+  connect(editFormatsFromTagButton, &QPushButton::clicked,
+          this, &ConfigDialogPages::editFormatsFromTag);
+  formatLayout->addWidget(editFormatsFromTagButton);
+  auto editFormatsToTagButton =
+          new QPushButton(tr("Tag from filename") + QLatin1String("..."));
+  connect(editFormatsToTagButton, &QPushButton::clicked,
+          this, &ConfigDialogPages::editFormatsToTag);
+  formatLayout->addWidget(editFormatsToTagButton);
+  rightLayout->addWidget(formatGroupBox);
+
   rightLayout->addStretch();
 
   hlayout->addLayout(leftLayout);
@@ -424,6 +442,38 @@ QWidget* ConfigDialogPages::createFilesPage()
   return filesPage;
 }
 
+/**
+ * Open dialog to edit "Filename from tag" formats.
+ */
+void ConfigDialogPages::editFormatsFromTag()
+{
+  QWidget* parentWindow = nullptr;
+  if (auto button = qobject_cast<QPushButton*>(sender())) {
+    parentWindow = button->window();
+  }
+  StringListEditDialog dialog(
+        m_toFilenameFormats, tr("Filename from Tag"), parentWindow);
+  if (dialog.exec() == QDialog::Accepted) {
+    m_toFilenameFormats = dialog.stringList();
+  }
+}
+
+/**
+ * Open dialog to edit "Filename to tag" formats.
+ */
+void ConfigDialogPages::editFormatsToTag()
+{
+  QWidget* parentWindow = nullptr;
+  if (auto button = qobject_cast<QPushButton*>(sender())) {
+    parentWindow = button->window();
+  }
+  StringListEditDialog dialog(
+        m_fromFilenameFormats, tr("Tag from Filename"), parentWindow);
+  if (dialog.exec() == QDialog::Accepted) {
+    m_fromFilenameFormats = dialog.stringList();
+  }
+}
+
 /**
  * Create page with actions settings.
  * @return actions page.
@@ -431,25 +481,26 @@ QWidget* ConfigDialogPages::createFilesPage()
 QWidget* ConfigDialogPages::createActionsPage()
 {
   QWidget* actionsPage = new QWidget;
-  QVBoxLayout* vlayout = new QVBoxLayout(actionsPage);
+  auto vlayout = new QVBoxLayout(actionsPage);
   QGroupBox* browserGroupBox = new QGroupBox(tr("Browser"), actionsPage);
   QLabel* browserLabel = new QLabel(tr("Web &browser:"), browserGroupBox);
   m_browserLineEdit = new QLineEdit(browserGroupBox);
   browserLabel->setBuddy(m_browserLineEdit);
-  QHBoxLayout* hbox = new QHBoxLayout;
+  auto hbox = new QHBoxLayout;
   hbox->addWidget(browserLabel);
   hbox->addWidget(m_browserLineEdit);
   browserGroupBox->setLayout(hbox);
   vlayout->addWidget(browserGroupBox);
 
-  QGroupBox* commandsGroupBox = new QGroupBox(tr("Context &Menu Commands"), actionsPage);
+  QGroupBox* commandsGroupBox = new QGroupBox(tr("Context &Menu Commands"),
+                                              actionsPage);
   m_playOnDoubleClickCheckBox =
       new QCheckBox(tr("&Play on double click"), commandsGroupBox);
   m_commandsTableModel = new CommandsTableModel(commandsGroupBox);
   m_commandsTable = new ConfigTable(m_commandsTableModel, commandsGroupBox);
   m_commandsTable->setHorizontalResizeModes(
     m_commandsTableModel->getHorizontalResizeModes());
-  QVBoxLayout* commandsLayout = new QVBoxLayout;
+  auto commandsLayout = new QVBoxLayout;
   commandsLayout->addWidget(m_playOnDoubleClickCheckBox);
   commandsLayout->addWidget(m_commandsTable);
   commandsGroupBox->setLayout(commandsLayout);
@@ -464,25 +515,28 @@ QWidget* ConfigDialogPages::createActionsPage()
 QWidget* ConfigDialogPages::createNetworkPage()
 {
   QWidget* networkPage = new QWidget;
-  QVBoxLayout* vlayout = new QVBoxLayout(networkPage);
+  auto vlayout = new QVBoxLayout(networkPage);
   QGroupBox* proxyGroupBox = new QGroupBox(tr("Proxy"), networkPage);
   m_proxyCheckBox = new QCheckBox(tr("&Proxy:"), proxyGroupBox);
   m_proxyLineEdit = new QLineEdit(proxyGroupBox);
-  m_proxyAuthenticationCheckBox = new QCheckBox(tr("&Use authentication with proxy"), proxyGroupBox);
-  QLabel* proxyUserNameLabel = new QLabel(tr("Proxy user &name:"), proxyGroupBox);
+  m_proxyAuthenticationCheckBox = new QCheckBox(
+        tr("&Use authentication with proxy"), proxyGroupBox);
+  QLabel* proxyUserNameLabel =
+      new QLabel(tr("Proxy user &name:"), proxyGroupBox);
   m_proxyUserNameLineEdit = new QLineEdit(proxyGroupBox);
   proxyUserNameLabel->setBuddy(m_proxyUserNameLineEdit);
-  QLabel* proxyPasswordLabel = new QLabel(tr("Proxy pass&word:"), proxyGroupBox);
+  QLabel* proxyPasswordLabel =
+      new QLabel(tr("Proxy pass&word:"), proxyGroupBox);
   m_proxyPasswordLineEdit = new QLineEdit(proxyGroupBox);
   proxyPasswordLabel->setBuddy(m_proxyPasswordLineEdit);
   m_proxyPasswordLineEdit->setEchoMode(QLineEdit::Password);
-  QVBoxLayout* vbox = new QVBoxLayout;
-  QHBoxLayout* proxyHbox = new QHBoxLayout;
+  auto vbox = new QVBoxLayout;
+  auto proxyHbox = new QHBoxLayout;
   proxyHbox->addWidget(m_proxyCheckBox);
   proxyHbox->addWidget(m_proxyLineEdit);
   vbox->addLayout(proxyHbox);
   vbox->addWidget(m_proxyAuthenticationCheckBox);
-  QGridLayout* authLayout = new QGridLayout;
+  auto authLayout = new QGridLayout;
   authLayout->addWidget(proxyUserNameLabel, 0, 0);
   authLayout->addWidget(m_proxyUserNameLineEdit, 0, 1);
   authLayout->addWidget(proxyPasswordLabel, 1, 0);
@@ -491,7 +545,8 @@ QWidget* ConfigDialogPages::createNetworkPage()
   proxyGroupBox->setLayout(vbox);
   vlayout->addWidget(proxyGroupBox);
 
-  QSpacerItem* vspacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);
+  auto vspacer = new QSpacerItem(0, 0,
+                                 QSizePolicy::Minimum, QSizePolicy::Expanding);
   vlayout->addItem(vspacer);
   return networkPage;
 }
@@ -503,23 +558,23 @@ QWidget* ConfigDialogPages::createNetworkPage()
 QWidget* ConfigDialogPages::createPluginsPage()
 {
   QWidget* pluginsPage = new QWidget;
-  QVBoxLayout* vlayout = new QVBoxLayout(pluginsPage);
+  auto vlayout = new QVBoxLayout(pluginsPage);
   QGroupBox* metadataGroupBox = new QGroupBox(
         tr("&Metadata Plugins && Priority"), pluginsPage);
 
 
-  QVBoxLayout* metadataPluginsLayout = new QVBoxLayout(metadataGroupBox);
+  auto metadataPluginsLayout = new QVBoxLayout(metadataGroupBox);
   m_enabledMetadataPluginsModel =
       new CheckableStringListModel(metadataGroupBox);
-  StringListEdit* metadataEdit =
+  auto metadataEdit =
       new StringListEdit(m_enabledMetadataPluginsModel, metadataGroupBox);
   metadataEdit->setEditingDisabled(true);
   metadataPluginsLayout->addWidget(metadataEdit);
   vlayout->addWidget(metadataGroupBox);
 
   QGroupBox* pluginsGroupBox = new QGroupBox(tr("A&vailable Plugins"));
-  QVBoxLayout* pluginsLayout = new QVBoxLayout(pluginsGroupBox);
-  QListView* pluginsListView = new QListView;
+  auto pluginsLayout = new QVBoxLayout(pluginsGroupBox);
+  auto pluginsListView = new QListView;
   pluginsListView->setSelectionMode(QAbstractItemView::NoSelection);
   m_enabledPluginsModel = new CheckableStringListModel(pluginsGroupBox);
   pluginsListView->setModel(m_enabledPluginsModel);
@@ -597,6 +652,8 @@ void ConfigDialogPages::setConfigs(
         folderPatternListToString(fileCfg.excludeFolders(), false));
   m_showHiddenFilesCheckBox->setChecked(fileCfg.showHiddenFiles());
   m_fileTextEncodingComboBox->setCurrentIndex(fileCfg.textEncodingIndex());
+  m_toFilenameFormats = fileCfg.toFilenameFormats();
+  m_fromFilenameFormats = fileCfg.fromFilenameFormats();
   m_onlyCustomGenresCheckBox->setChecked(tagCfg.onlyCustomGenres());
   m_genresEditModel->setStringList(tagCfg.customGenres());
   m_starRatingMappingsModel->setMappings(tagCfg.starRatingMappings());
@@ -604,14 +661,17 @@ void ConfigDialogPages::setConfigs(
   QList<int> frameTypes = tagCfg.quickAccessFrameOrder();
   if (frameTypes.size() != Frame::FT_LastFrame + 1) {
     frameTypes.clear();
+    frameTypes.reserve(Frame::FT_LastFrame - Frame::FT_FirstFrame + 1);
     for (int i = Frame::FT_FirstFrame; i <= Frame::FT_LastFrame; ++i) {
       frameTypes.append(i);
     }
   }
   m_quickAccessTagsModel->clear();
-  foreach (int frameType, frameTypes) {
+  const auto constFrameTypes = frameTypes;
+  for (int frameType : constFrameTypes) {
     QStandardItem* item = new QStandardItem(
-          Frame::ExtendedType(static_cast<Frame::Type>(frameType)).getTranslatedName());
+          Frame::ExtendedType(static_cast<Frame::Type>(frameType))
+          .getTranslatedName());
     item->setData(frameType, Qt::UserRole);
     item->setCheckable(true);
     item->setCheckState((frameMask & (1ULL << frameType))
@@ -657,14 +717,15 @@ void ConfigDialogPages::setConfigs(
   QStringList pluginOrder = tagCfg.pluginOrder();
   if (!pluginOrder.isEmpty()) {
     for (int i = 0; i < pluginOrder.size(); ++i) {
-      metadataPlugins.append(QString());
+      metadataPlugins.append(QString()); // clazy:exclude=reserve-candidates
     }
-    foreach (const QString& pluginName, tagCfg.availablePlugins()) {
+    const auto pluginNames = tagCfg.availablePlugins();
+    for (const QString& pluginName : pluginNames) {
       int pluginIdx = pluginOrder.indexOf(pluginName);
       if (pluginIdx >= 0) {
         metadataPlugins[pluginIdx] = pluginName;
       } else {
-        metadataPlugins.append(pluginName);
+        metadataPlugins.append(pluginName); // clazy:exclude=reserve-candidates
       }
     }
     metadataPlugins.removeAll(QString());
@@ -723,25 +784,24 @@ void ConfigDialogPages::getConfig() const
   fileCfg.setPreserveTime(m_preserveTimeCheckBox->isChecked());
   fileCfg.setMarkChanges(m_markChangesCheckBox->isChecked());
   fileCfg.setDefaultCoverFileName(m_coverFileNameLineEdit->text());
-#if QT_VERSION >= 0x050200
   fileCfg.setNameFilter(m_nameFilterComboBox->currentData().toString());
-#else
-  fileCfg.setNameFilter(m_nameFilterComboBox->itemData(
-                          m_nameFilterComboBox->currentIndex()).toString());
-#endif
   fileCfg.setIncludeFolders(
         folderPatternListFromString(m_includeFoldersLineEdit->text(), true));
   fileCfg.setExcludeFolders(
         folderPatternListFromString(m_excludeFoldersLineEdit->text(), false));
   fileCfg.setShowHiddenFiles(m_showHiddenFilesCheckBox->isChecked());
   fileCfg.setTextEncodingIndex(m_fileTextEncodingComboBox->currentIndex());
+  fileCfg.setToFilenameFormats(m_toFilenameFormats);
+  fileCfg.setFromFilenameFormats(m_fromFilenameFormats);
   tagCfg.setOnlyCustomGenres(m_onlyCustomGenresCheckBox->isChecked());
   tagCfg.setCustomGenres(m_genresEditModel->stringList());
   tagCfg.setStarRatingMappings(m_starRatingMappingsModel->getMappings());
   QList<int> frameTypes;
   bool isStandardFrameOrder = true;
   quint64 frameMask = 0;
-  for (int row = 0; row < m_quickAccessTagsModel->rowCount(); ++row) {
+  const int numQuickAccessTags = m_quickAccessTagsModel->rowCount();
+  frameTypes.reserve(numQuickAccessTags);
+  for (int row = 0; row < numQuickAccessTags; ++row) {
     QModelIndex index = m_quickAccessTagsModel->index(row, 0);
     int frameType = index.data(Qt::UserRole).toInt();
     if (frameType != row) {
@@ -781,13 +841,15 @@ void ConfigDialogPages::getConfig() const
   networkCfg.setProxyPassword(m_proxyPasswordLineEdit->text());
 
   QStringList pluginOrder, disabledPlugins;
-  for (int row = 0; row < m_enabledMetadataPluginsModel->rowCount(); ++row) {
+  const int numPlugins = m_enabledMetadataPluginsModel->rowCount();
+  pluginOrder.reserve(numPlugins);
+  for (int row = 0; row < numPlugins; ++row) {
     QString pluginName =
         m_enabledMetadataPluginsModel->index(row).data().toString();
     pluginOrder.append(pluginName);
-    if (m_enabledMetadataPluginsModel->index(row).data(Qt::CheckStateRole).
-        toInt() != Qt::Checked) {
-      disabledPlugins.append(pluginName);
+    if (m_enabledMetadataPluginsModel->index(row).data(Qt::CheckStateRole)
+        .toInt() != Qt::Checked) {
+      disabledPlugins.append(pluginName); // clazy:exclude=reserve-candidates
     }
   }
   tagCfg.setPluginOrder(pluginOrder);
@@ -795,8 +857,8 @@ void ConfigDialogPages::getConfig() const
 
   disabledPlugins.clear();
   for (int row = 0; row < m_enabledPluginsModel->rowCount(); ++row) {
-    if (m_enabledPluginsModel->index(row).data(Qt::CheckStateRole).
-        toInt() != Qt::Checked) {
+    if (m_enabledPluginsModel->index(row).data(Qt::CheckStateRole)
+        .toInt() != Qt::Checked) {
       disabledPlugins.append(
             m_enabledPluginsModel->index(row).data().toString());
     }
