@@ -25,6 +25,7 @@
  */
 
 #include "basemainwindow.h"
+#include <QTimer>
 #include <QDir>
 #include <QCursor>
 #include <QMessageBox>
@@ -45,6 +46,7 @@
 #include "frametablemodel.h"
 #include "frametable.h"
 #include "importdialog.h"
+#include "tagimportdialog.h"
 #include "batchimportdialog.h"
 #include "browsecoverartdialog.h"
 #include "exportdialog.h"
@@ -96,16 +98,29 @@ BaseMainWindowImpl::BaseMainWindowImpl(QMainWindow* mainWin,
                                        IPlatformTools* platformTools,
                                        Kid3Application* app)
   : m_platformTools(platformTools), m_w(mainWin), m_self(nullptr),
-    m_form(nullptr), m_app(app),
+    m_deferredItemCountTimer(new QTimer(this)),
+    m_deferredSelectionCountTimer(new QTimer(this)),
+    m_statusLabel(nullptr), m_form(nullptr), m_app(app),
     m_exportDialog(nullptr), m_findReplaceDialog(nullptr),
     m_downloadDialog(new DownloadDialog(m_w, tr("Download"))),
-    m_progressWidget(nullptr),
+    m_progressWidget(nullptr), m_progressLabel(nullptr),
     m_progressBar(nullptr), m_progressAbortButton(nullptr),
     m_editFrameDialog(nullptr), m_editFrameTaggedFile(nullptr),
     m_editFrameTagNr(Frame::Tag_2),
-    m_progressTerminationHandler(nullptr),  m_progressDisconnected(false),
+    m_progressTerminationHandler(nullptr),
+    m_folderCount(0), m_fileCount(0), m_selectionCount(0),
+    m_progressDisconnected(false),
     m_findReplaceActive(false), m_expandNotificationNeeded(false)
 {
+  m_deferredItemCountTimer->setSingleShot(true);
+  m_deferredItemCountTimer->setInterval(1000);
+  connect(m_deferredItemCountTimer, &QTimer::timeout,
+          this, &BaseMainWindowImpl::onItemCountChanged);
+  m_deferredSelectionCountTimer->setSingleShot(true);
+  m_deferredSelectionCountTimer->setInterval(500);
+  connect(m_deferredSelectionCountTimer, &QTimer::timeout,
+          this, &BaseMainWindowImpl::onSelectionCountChanged);
+
   m_downloadDialog->close();
   ContextHelp::init(m_platformTools);
 
@@ -163,7 +178,8 @@ BaseMainWindowImpl::~BaseMainWindowImpl()
  */
 void BaseMainWindowImpl::init()
 {
-  m_w->statusBar()->showMessage(tr("Ready."));
+  m_statusLabel = new QLabel;
+  m_w->statusBar()->addWidget(m_statusLabel);
   m_form = new Kid3Form(m_app, this, m_w);
   m_w->setCentralWidget(m_form);
 
@@ -185,11 +201,11 @@ void BaseMainWindowImpl::confirmedOpenDirectory(const QStringList& paths)
     return;
   }
   QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-  slotStatusMsg(tr("Opening directory..."));
+  slotStatusMsg(tr("Opening folder..."));
 
   m_app->openDirectory(paths, false);
 
-  slotStatusMsg(tr("Ready."));
+  slotClearStatusMsg();
   QApplication::restoreOverrideCursor();
 }
 
@@ -235,6 +251,9 @@ void BaseMainWindowImpl::showOperationProgress(const QString& name,
 {
   if (done == -1) {
     // Operation started.
+    if (!m_progressLabel) {
+      m_progressLabel = new QLabel;
+    }
     if (!m_progressBar) {
       m_progressBar = new QProgressBar;
     }
@@ -245,15 +264,24 @@ void BaseMainWindowImpl::showOperationProgress(const QString& name,
       m_progressAbortButton->setToolTip(tr("Abort"));
       m_progressAbortButton->setCheckable(true);
     }
-    m_w->statusBar()->addPermanentWidget(m_progressBar);
-    m_w->statusBar()->addPermanentWidget(m_progressAbortButton);
+    if (m_statusLabel) {
+      m_w->statusBar()->removeWidget(m_statusLabel);
+    }
+    m_w->statusBar()->addPermanentWidget(m_progressLabel);
+    m_w->statusBar()->addPermanentWidget(m_progressBar, 1);
+    m_w->statusBar()->addPermanentWidget(m_progressAbortButton, 1);
+    m_progressLabel->setText(name);
     m_progressBar->setMinimum(0);
     m_progressBar->setMaximum(total);
     m_progressBar->setValue(0);
     m_progressAbortButton->setChecked(false);
-    slotStatusMsg(name);
   } else if (done == total && total != 0) {
     // Operation finished.
+    if (m_progressLabel) {
+      m_w->statusBar()->removeWidget(m_progressLabel);
+      delete m_progressLabel;
+      m_progressLabel = nullptr;
+    }
     if (m_progressBar) {
       m_w->statusBar()->removeWidget(m_progressBar);
       delete m_progressBar;
@@ -263,8 +291,12 @@ void BaseMainWindowImpl::showOperationProgress(const QString& name,
       m_w->statusBar()->removeWidget(m_progressAbortButton);
       delete m_progressAbortButton;
       m_progressAbortButton = nullptr;
+      if (m_statusLabel) {
+        m_w->statusBar()->addWidget(m_statusLabel);
+        m_statusLabel->show();
+      }
     }
-    slotStatusMsg(tr("Ready."));
+    slotClearStatusMsg();
   } else if (done < total || (done == 0 && total == 0)) {
     // Operation progress.
     if (m_progressBar) {
@@ -367,7 +399,7 @@ bool BaseMainWindowImpl::saveModified(bool doNotRevert)
   {
     int want_save = m_platformTools->warningYesNoCancel(
         m_w,
-        tr("The current directory has been modified.\n"
+        tr("The current folder has been modified.\n"
        "Do you want to save it?"),
         tr("Warning"));
     switch(want_save)
@@ -521,8 +553,104 @@ void BaseMainWindowImpl::slotFileQuit()
 {
   slotStatusMsg(tr("Exiting..."));
   m_w->close(); /* this will lead to call of closeEvent(), queryClose() */
+  slotClearStatusMsg();
 }
 
+/**
+ * Change visibility of status bar.
+ * @param visible true to show status bar
+ */
+void BaseMainWindowImpl::setStatusBarVisible(bool visible)
+{
+  auto model =
+      qobject_cast<FileProxyModel*>(m_form->getFileList()->model());
+  auto selModel = m_app->getFileSelectionModel();
+  if (visible) {
+    m_w->statusBar()->show();
+    if (model && selModel) {
+      connect(model, &FileProxyModel::sortingFinished,
+              m_deferredItemCountTimer,
+              static_cast<void (QTimer::*)()>(&QTimer::start),
+              Qt::UniqueConnection);
+      connect(model->sourceModel(), &QAbstractItemModel::dataChanged,
+              m_deferredItemCountTimer,
+              static_cast<void (QTimer::*)()>(&QTimer::start),
+              Qt::UniqueConnection);
+      connect(selModel, &QItemSelectionModel::selectionChanged,
+              m_deferredSelectionCountTimer,
+              static_cast<void (QTimer::*)()>(&QTimer::start),
+              Qt::UniqueConnection);
+    }
+    onItemCountChanged();
+    onSelectionCountChanged();
+  } else {
+    m_deferredItemCountTimer->stop();
+    m_deferredSelectionCountTimer->stop();
+    m_w->statusBar()->hide();
+    if (model && selModel) {
+      disconnect(model, &FileProxyModel::sortingFinished,
+                 m_deferredItemCountTimer,
+                 static_cast<void (QTimer::*)()>(&QTimer::start));
+      disconnect(model->sourceModel(), &QAbstractItemModel::dataChanged,
+                 m_deferredItemCountTimer,
+                 static_cast<void (QTimer::*)()>(&QTimer::start));
+      disconnect(selModel, &QItemSelectionModel::selectionChanged,
+                 m_deferredSelectionCountTimer,
+                 static_cast<void (QTimer::*)()>(&QTimer::start));
+    }
+    m_folderCount = 0;
+    m_fileCount = 0;
+    m_selectionCount = 0;
+    updateStatusLabel();
+  }
+}
+
+/**
+ * Called when the item count of the file proxy model changed.
+ */
+void BaseMainWindowImpl::onItemCountChanged()
+{
+  if (auto model =
+      qobject_cast<FileProxyModel*>(m_form->getFileList()->model())) {
+    model->countItems(m_app->getRootIndex(), m_folderCount, m_fileCount);
+    updateStatusLabel();
+  }
+}
+
+/**
+ * Called when the item count of the file selection model changed.
+ */
+void BaseMainWindowImpl::onSelectionCountChanged()
+{
+  if (auto selModel = m_app->getFileSelectionModel()) {
+    m_selectionCount = selModel->selectedRows().size();
+    updateStatusLabel();
+  }
+}
+
+/**
+ * Update label of status bar with information about the number of files.
+ */
+void BaseMainWindowImpl::updateStatusLabel()
+{
+  if (m_statusLabel) {
+    QStringList counts;
+    if (m_folderCount != 0) {
+      counts.append(tr("%n folders", "", m_folderCount));
+    }
+    if (m_fileCount != 0) {
+      counts.append(tr("%n files", "", m_fileCount));
+    }
+    if (m_selectionCount != 0) {
+      counts.append(tr("%n selected", "", m_selectionCount));
+    }
+    if (counts.isEmpty()) {
+      m_statusLabel->setText((tr("Ready.")));
+    } else {
+      m_statusLabel->setText(counts.join(QLatin1String(", ")));
+    }
+  }
+}
 
 /**
  * Change status message.
@@ -538,6 +666,15 @@ void BaseMainWindowImpl::slotStatusMsg(const QString& text)
   qApp->processEvents();
 }
 
+/**
+ * Clear status message.
+ * To be called when a message set with slotStatusMsg() is no longer valid.
+ */
+void BaseMainWindowImpl::slotClearStatusMsg()
+{
+  m_w->statusBar()->clearMessage();
+}
+
 /**
  * Show playlist dialog.
  */
@@ -574,7 +711,7 @@ bool BaseMainWindowImpl::writePlaylist(const PlaylistConfig& cfg)
 
   bool ok = m_app->writePlaylist(cfg);
 
-  slotStatusMsg(tr("Ready."));
+  slotClearStatusMsg();
   QApplication::restoreOverrideCursor();
   return ok;
 }
@@ -679,6 +816,25 @@ void BaseMainWindowImpl::slotImport()
   }
 }
 
+/**
+ * Tag import.
+ */
+void BaseMainWindowImpl::slotTagImport()
+{
+  if (!m_tagImportDialog) {
+    m_tagImportDialog.reset(new TagImportDialog(m_w, nullptr));
+    connect(m_tagImportDialog.data(), &TagImportDialog::trackDataUpdated,
+            this, [this]() {
+      m_app->importFromTagsToSelection(
+            m_tagImportDialog->getDestination(),
+            m_tagImportDialog->getSourceFormat(),
+            m_tagImportDialog->getExtractionFormat());
+    });
+  }
+  m_tagImportDialog->clear();
+  m_tagImportDialog->show();
+}
+
 /**
  * Batch import.
  */
@@ -1012,20 +1168,23 @@ void BaseMainWindowImpl::slotPlayAudio()
 void BaseMainWindowImpl::showPlayToolBar()
 {
   if (!m_playToolBar) {
-    m_playToolBar.reset(new PlayToolBar(m_app->getAudioPlayer(), m_w));
-    m_playToolBar->setAllowedAreas(Qt::TopToolBarArea | Qt::BottomToolBarArea);
-    m_w->addToolBar(Qt::BottomToolBarArea, m_playToolBar.data());
-    connect(m_playToolBar.data(), &PlayToolBar::errorMessage,
-            this, &BaseMainWindowImpl::slotStatusMsg);
+    if (AudioPlayer* player =
+        qobject_cast<AudioPlayer*>(m_app->getAudioPlayer())) {
+      m_playToolBar.reset(new PlayToolBar(player, m_w));
+      m_playToolBar->setAllowedAreas(Qt::TopToolBarArea | Qt::BottomToolBarArea);
+      m_w->addToolBar(Qt::BottomToolBarArea, m_playToolBar.data());
+      connect(m_playToolBar.data(), &PlayToolBar::errorMessage,
+              this, &BaseMainWindowImpl::slotStatusMsg);
 #ifdef HAVE_QTDBUS
-    connect(m_playToolBar.data(), &PlayToolBar::closed,
-            m_app, &Kid3Application::deactivateMprisInterface);
+      connect(m_playToolBar.data(), &PlayToolBar::closed,
+              m_app, &Kid3Application::deactivateMprisInterface);
 #endif
 #ifdef Q_OS_WIN32
-    // Phonon on Windows cannot play if the file is open.
-    connect(m_playToolBar.data(), &PlayToolBar::aboutToPlay,
-            m_app, &Kid3Application::closeFileHandle);
+      // Phonon on Windows cannot play if the file is open.
+      connect(m_playToolBar.data(), &PlayToolBar::aboutToPlay,
+              m_app, &Kid3Application::closeFileHandle);
 #endif
+    }
   }
   m_playToolBar->show();
 }
@@ -1158,9 +1317,15 @@ void BaseMainWindowImpl::selectFrame(Frame* frame, const TaggedFile* taggedFile)
       m_w, tr("Add Frame"),
       tr("Select the frame ID"), nameMap.keys(), 0, true, &ok);
     if (ok) {
-      QString name = nameMap.value(displayName, displayName);
-      Frame::Type type = Frame::getTypeFromName(name);
-      *frame = Frame(type, QLatin1String(""), name, -1);
+      if (displayName.startsWith(QLatin1Char('!'))) {
+        QString name = displayName.mid(1);
+        Frame::ExtendedType type(Frame::FT_Other, name);
+        *frame = Frame(type, QLatin1String(""), -1);
+      } else {
+        QString name = nameMap.value(displayName, displayName);
+        Frame::Type type = Frame::getTypeFromName(name);
+        *frame = Frame(type, QLatin1String(""), name, -1);
+      }
     }
   }
   emit frameSelected(m_editFrameTagNr, ok ? frame : nullptr);
@@ -1328,7 +1493,7 @@ void BaseMainWindowImpl::renameFile()
               0, tr("File Error"),
               tr("Error while renaming:\n") +
               tr("Rename %1 to %2 failed\n").arg(fileName).arg(newFileName) +
-              tr("Retry after closing directories?"),
+              tr("Retry after closing folders?"),
               QMessageBox::Ok, QMessageBox::Cancel) == QMessageBox::Ok) {
           m_app->tryRenameAfterReset(absFilename, newPath);
         }
@@ -1408,7 +1573,7 @@ void BaseMainWindowImpl::deleteFile()
       if (!files.isEmpty()) {
         QString txt;
         if (rmdirError)
-          txt += tr("Directory must be empty.\n");
+          txt += tr("Folder must be empty.\n");
         txt += tr("Could not move these files to the Trash");
         m_platformTools->errorList(m_w, txt, files, tr("File Error"));
       }
@@ -1612,13 +1777,12 @@ void BaseMainWindow::slotPlayAudio()
 }
 
 /**
- * Change status message.
- *
- * @param text message
+ * Change visibility of status bar.
+ * @param visible true to show status bar
  */
-void BaseMainWindow::slotStatusMsg(const QString& text)
+void BaseMainWindow::setStatusBarVisible(bool visible)
 {
-  m_impl->slotStatusMsg(text);
+  m_impl->setStatusBarVisible(visible);
 }
 
 /**
