@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 3 Jan 2014
  *
- * Copyright (C) 2014-2017  Urs Fleisch
+ * Copyright (C) 2014-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CONFIGURABLETREEVIEW_H
-#define CONFIGURABLETREEVIEW_H
+#pragma once
 
 #include <QTreeView>
 
@@ -39,12 +38,12 @@ public:
    * Constructor.
    * @param parent parent widget
    */
-  explicit ConfigurableTreeView(QWidget* parent = 0);
+  explicit ConfigurableTreeView(QWidget* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~ConfigurableTreeView();
+  virtual ~ConfigurableTreeView() override = default;
 
   /**
    * Set visible columns.
@@ -100,5 +99,3 @@ private:
   QItemSelectionModel* m_oldSelectionModel;
   QPersistentModelIndex m_oldRootIndex;
 };
-
-#endif // CONFIGURABLETREEVIEW_H
