@@ -50,6 +50,7 @@
 #include <QFileIconProvider>
 #include <QStyle>
 #include <QHeaderView>
+#include <QBuffer>
 #include "filesystemmodel.h"
 #include "frametable.h"
 #include "frametablemodel.h"
@@ -58,6 +59,7 @@
 #include "basemainwindow.h"
 #include "filelist.h"
 #include "framelist.h"
+#include "pictureframe.h"
 #include "configurabletreeview.h"
 #include "picturelabel.h"
 #include "fileconfig.h"
@@ -66,7 +68,7 @@
 #include "dirproxymodel.h"
 #include "fileproxymodel.h"
 #include "filesystemmodel.h"
-#include "taggedfileiconprovider.h"
+#include "coretaggedfileiconprovider.h"
 #include "kid3application.h"
 #ifdef Q_OS_MAC
 #include <CoreFoundation/CFURL.h>
@@ -285,7 +287,7 @@ Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
           qobject_cast<FileSystemModel*>(fileProxyModel->sourceModel())) {
     fsModel->setDecorationProvider(m_iconProvider.data());
   }
-  TaggedFileIconProvider* tagIconProvider = fileProxyModel->getIconProvider();
+  CoreTaggedFileIconProvider* tagIconProvider = fileProxyModel->getIconProvider();
   tagIconProvider->setModifiedIcon(
         QApplication::style()->standardIcon(QStyle::SP_DriveFDIcon));
   int iconHeight = (((fontMetrics().height() - 1) / 16) + 1) * 16;
@@ -632,8 +634,16 @@ void Kid3Form::dropEvent(QDropEvent* ev)
   if (ev->mimeData()->hasImage()) {
     QImage image = qvariant_cast<QImage>(ev->mimeData()->imageData());
     ev->acceptProposedAction();
-    m_app->dropImage(image);
-    return;
+    if (!image.isNull()) {
+      QByteArray ba;
+      QBuffer buffer(&ba);
+      buffer.open(QIODevice::WriteOnly);
+      image.save(&buffer, "JPG");
+      PictureFrame frame;
+      if (PictureFrame::setData(frame, ba)) {
+        m_app->dropImage(&frame);
+      }
+    }
   } else if (ev->mimeData()->hasFormat(QLatin1String("text/uri-list"))) {
     QList<QUrl> urls = ev->mimeData()->urls();
     ev->acceptProposedAction();
