@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 28 May 2011
  *
- * Copyright (C) 2011-2013  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -31,19 +31,12 @@
  * Constructor.
  * @param parent parent object
  */
-ComboBoxDelegate::ComboBoxDelegate(QObject* parent) :
-  QStyledItemDelegate(parent)
+ComboBoxDelegate::ComboBoxDelegate(QObject* parent)
+  : QStyledItemDelegate(parent)
 {
   setObjectName(QLatin1String("ComboBoxDelegate"));
 }
 
-/**
- * Destructor.
- */
-ComboBoxDelegate::~ComboBoxDelegate()
-{
-}
-
 /**
  * Create an editor to edit the cells contents.
  * @param parent parent widget
@@ -59,7 +52,7 @@ QWidget* ComboBoxDelegate::createEditor(
   if (itemsData.isValid() && itemsData.type() == QVariant::StringList) {
     QStringList items(itemsData.toStringList());
     int itemIndex = items.indexOf(index.data(Qt::EditRole).toString());
-    QComboBox* cb = new QComboBox(parent);
+    auto cb = new QComboBox(parent);
     cb->addItems(itemsData.toStringList());
     if (itemIndex >= 0)
       cb->setCurrentIndex(itemIndex);
@@ -77,7 +70,7 @@ QWidget* ComboBoxDelegate::createEditor(
 void ComboBoxDelegate::setEditorData(QWidget* editor,
                                      const QModelIndex& index) const
 {
-  if (QComboBox* cb = qobject_cast<QComboBox*>(editor)) {
+  if (auto cb = qobject_cast<QComboBox*>(editor)) {
     int itemIndex = cb->findText(index.data(Qt::EditRole).toString());
     if (itemIndex >= 0)
       cb->setCurrentIndex(itemIndex);
@@ -95,7 +88,7 @@ void ComboBoxDelegate::setEditorData(QWidget* editor,
 void ComboBoxDelegate::setModelData(QWidget* editor, QAbstractItemModel* model,
                                     const QModelIndex& index) const
 {
-  if (QComboBox* cb = qobject_cast<QComboBox*>(editor))
+  if (auto cb = qobject_cast<QComboBox*>(editor))
     model->setData(index, cb->currentText(), Qt::EditRole);
   else
     QStyledItemDelegate::setModelData(editor, model, index);
