@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Sep 2003
  *
- * Copyright (C) 2003-2012  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef FORMATBOX_H
-#define FORMATBOX_H
+#pragma once
 
 #include <QGroupBox>
 
@@ -48,12 +47,12 @@ public:
    * @param title  title
    * @param parent parent widget
    */
-  explicit FormatBox(const QString& title, QWidget* parent = 0);
+  explicit FormatBox(const QString& title, QWidget* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~FormatBox();
+  virtual ~FormatBox() override = default;
 
   /**
    * Set the values from a format configuration.
@@ -71,13 +70,9 @@ public:
 
 private:
   QComboBox* m_caseConvComboBox;
-#if QT_VERSION >= 0x040800
   QComboBox* m_localeComboBox;
-#endif
   QCheckBox* m_strRepCheckBox;
   ConfigTable* m_strReplTable;
   ConfigTableModel* m_strReplTableModel;
   QCheckBox* m_formatEditingCheckBox;
 };
-
-#endif
