@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 05 Sep 2007
  *
- * Copyright (C) 2007-2011  Urs Fleisch
+ * Copyright (C) 2007-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,34 +24,35 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef FRAMETABLE_H
-#define FRAMETABLE_H
+#pragma once
 
 #include <QTableView>
 
 class QAction;
 class QPoint;
 class FrameTableModel;
+class GenreModel;
 
 /**
  * Table to edit frames.
  */
 class FrameTable : public QTableView {
-Q_OBJECT
-
+  Q_OBJECT
 public:
   /**
    * Constructor.
    *
    * @param model frame table model
+   * @param genreModel genre model
    * @param parent parent widget
    */
-  explicit FrameTable(FrameTableModel* model, QWidget* parent = 0);
+  explicit FrameTable(FrameTableModel* model, GenreModel* genreModel,
+                      QWidget* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~FrameTable();
+  virtual ~FrameTable() override = default;
 
   /**
    * Filters events if this object has been installed as an event filter
@@ -62,7 +63,7 @@ public:
    * @param event   event
    * @return true to filter event out.
    */
-  virtual bool eventFilter(QObject* watched, QEvent* event);
+  virtual bool eventFilter(QObject* watched, QEvent* event) override;
 
   /**
    * Commit data from the current editor.
@@ -107,5 +108,3 @@ private slots:
 private:
   QWidget* m_currentEditor;
 };
-
-#endif // FRAMETABLE_H
