@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 15 Feb 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -29,8 +29,8 @@
 #include "ffmpegfingerprintdecoder.h"
 #include "acoustidconfig.h"
 
-#include <stdint.h>
-#include <stdio.h>
+#include <cstdint>
+#include <cstdio>
 extern "C" {
 #include <libavcodec/avcodec.h>
 #include <libavformat/avformat.h>
@@ -103,6 +103,9 @@ public:
     }
   }
 
+  Packet(const Packet&) = delete;
+  Packet& operator=(const Packet&) = delete;
+
   int streamIndex() const { return m_ptr ? m_ptr->stream_index : -1; }
 
 private:
@@ -111,7 +114,7 @@ private:
 
 class Codec {
 public:
-  Codec() : m_ptr(0), m_impl(0), m_frame(0), m_opened(false) {
+  Codec() : m_ptr(nullptr), m_impl(nullptr), m_frame(nullptr), m_opened(false) {
   }
 
   ~Codec() {
@@ -131,6 +134,9 @@ public:
 #endif
   }
 
+  Codec(const Codec&) = delete;
+  Codec& operator=(const Codec&) = delete;
+
   bool open() {
     m_opened = false;
     if (m_ptr && m_impl) {
@@ -138,7 +144,7 @@ public:
 #if LIBAVCODEC_VERSION_INT < AV_VERSION_INT(53, 5, 0)
         ::avcodec_open(m_ptr, m_impl) >= 0
 #else
-        ::avcodec_open2(m_ptr, m_impl, 0) >= 0
+        ::avcodec_open2(m_ptr, m_impl, nullptr) >= 0
 #endif
           ;
     }
@@ -233,18 +239,18 @@ private:
 
 class Format {
 public:
-  Format(const char* fileName) : m_ptr(0), m_streamIndex(-1), m_hasError(false) {
+  Format(const char* fileName) : m_ptr(nullptr), m_streamIndex(-1), m_hasError(false) {
     if (
 #if LIBAVFORMAT_VERSION_INT < AV_VERSION_INT(53, 2, 0)
         ::av_open_input_file(&m_ptr, fileName, 0, 0, 0) != 0
 #else
-        ::avformat_open_input(&m_ptr, fileName, 0, 0) != 0
+        ::avformat_open_input(&m_ptr, fileName, nullptr, nullptr) != 0
 #endif
         ||
 #if LIBAVFORMAT_VERSION_INT < AV_VERSION_INT(53, 5, 0)
         ::av_find_stream_info(m_ptr) < 0
 #else
-        ::avformat_find_stream_info(m_ptr, 0) < 0
+        ::avformat_find_stream_info(m_ptr, nullptr) < 0
 #endif
       )
       m_hasError = true;
@@ -259,10 +265,13 @@ public:
 #endif
   }
 
+  Format(const Format&) = delete;
+  Format& operator=(const Format&) = delete;
+
   bool hasError() const { return m_hasError; }
 
   AVStream* findAudioStream(Codec* codec) {
-    AVStream* stream = 0;
+    AVStream* stream = nullptr;
 #if LIBAVFORMAT_VERSION_INT < AV_VERSION_INT(52, 91, 0)
     for (unsigned i = 0; i < m_ptr->nb_streams; ++i) {
       codec->m_ptr = m_ptr->streams[i]->codec;
@@ -314,8 +323,8 @@ private:
 #if defined HAVE_AVRESAMPLE || defined HAVE_SWRESAMPLE
 class Converter {
 public:
-  Converter() : m_ptr(0), m_maxDstNumSamples(0), m_isOpen(false) {
-    m_dstData[0] = 0;
+  Converter() : m_ptr(nullptr), m_maxDstNumSamples(0), m_isOpen(false) {
+    m_dstData[0] = nullptr;
   }
 
   ~Converter() {
@@ -334,6 +343,9 @@ public:
     }
   }
 
+  Converter(const Converter&) = delete;
+  Converter& operator=(const Converter&) = delete;
+
   bool createForCodec(const Codec& codecCtx) {
     int64_t channelLayout = codecCtx.channelLayout();
     if (!channelLayout) {
@@ -352,9 +364,9 @@ public:
     }
 #elif defined HAVE_SWRESAMPLE
     if ((m_ptr = ::swr_alloc_set_opts(
-           0, channelLayout, AV_SAMPLE_FMT_S16, codecCtx.sampleRate(),
+           nullptr, channelLayout, AV_SAMPLE_FMT_S16, codecCtx.sampleRate(),
            channelLayout, codecCtx.sampleFormat(), codecCtx.sampleRate(),
-           0, 0)) != 0) {
+           0, nullptr)) != nullptr) {
       m_isOpen = ::swr_init(m_ptr) >= 0;
       return m_isOpen;
     }
@@ -374,7 +386,7 @@ public:
           int dstLinesize = 0;
           if (::av_samples_alloc(m_dstData, &dstLinesize, codecCtx.channels(),
                       codecCtx.m_frame->nb_samples, AV_SAMPLE_FMT_S16, 1) < 0) {
-            return 0;
+            return nullptr;
           }
           m_maxDstNumSamples = codecCtx.m_frame->nb_samples;
         }
@@ -426,9 +438,9 @@ public:
         result = buffer2;
       }
       if (numSamplesOut < 0) {
-        return 0;
+        return nullptr;
       }
-      bufferSize = ::av_samples_get_buffer_size(0, codecCtx.channels(),
+      bufferSize = ::av_samples_get_buffer_size(nullptr, codecCtx.channels(),
                    numSamplesOut, AV_SAMPLE_FMT_S16, 1);
       return result;
     } else {
@@ -501,10 +513,12 @@ public:
 }
 
 
-FFmpegFingerprintDecoder::FFmpegFingerprintDecoder(QObject* parent) :
-  AbstractFingerprintDecoder(parent)
+FFmpegFingerprintDecoder::FFmpegFingerprintDecoder(QObject* parent)
+  : AbstractFingerprintDecoder(parent)
 {
+#if LIBAVCODEC_VERSION_INT < AV_VERSION_INT(58, 9, 100)
   ::av_register_all();
+#endif
   ::av_log_set_level(AV_LOG_ERROR);
 
   m_buffer1 = reinterpret_cast<qint16*>(::av_malloc(BUFFER_SIZE + 16));
