@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 13 Dec 2009
  *
- * Copyright (C) 2009  Urs Fleisch
+ * Copyright (C) 2009-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef AMAZONCONFIG_H
-#define AMAZONCONFIG_H
+#pragma once
 
 #include "serverimporterconfig.h"
 
@@ -42,7 +41,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~AmazonConfig();
+  virtual ~AmazonConfig() override;
 
 private:
   friend AmazonConfig&
@@ -51,5 +50,3 @@ private:
   /** Index in configuration storage */
   static int s_index;
 };
-
-#endif // AMAZONCONFIG_H
