@@ -248,10 +248,10 @@ void DiscogsImporter::parseFindResults(const QByteArray& searchStr)
     QString artist = fixUpArtist(idTitleRe.cap(1).trimmed());
     QString title = removeHtml(idTitleRe.cap(4).trimmed());
     if (!title.isEmpty()) {
-      m_albumListModel->appendRow(new AlbumListItem(
+      m_albumListModel->appendItem(
         artist + QLatin1String(" - ") + title,
         idTitleRe.cap(2),
-        idTitleRe.cap(3)));
+        idTitleRe.cap(3));
     }
     pos += len;
   }
@@ -558,8 +558,8 @@ void DiscogsImporter::parseAlbumResults(const QByteArray& albumStr)
         if (indexRe.indexIn(trackDataStr) >= 0) {
           if (additionalTags) {
             QString subtitle(removeHtml(indexRe.cap(1)));
-            framesHdr.setValue(Frame::FT_Part, subtitle);
-            frames.setValue(Frame::FT_Part, subtitle);
+            framesHdr.setValue(Frame::FT_Description, subtitle);
+            frames.setValue(Frame::FT_Description, subtitle);
           }
           continue;
         }
