@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 15 Feb 2015
  *
- * Copyright (C) 2015  Urs Fleisch
+ * Copyright (C) 2015-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -26,60 +26,34 @@
 
 #include "qmlcommandplugin.h"
 #include <QDir>
-#if QT_VERSION >= 0x050000
+#ifndef NDEBUG
+#define QT_QML_DEBUG
+#endif
 #include <QQuickView>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
 #include <QQmlComponent>
 #include <QTimer>
-#else
-#include <QDeclarativeView>
-#include <QDeclarativeEngine>
-#include <QDeclarativeContext>
-#include <QDeclarativeComponent>
-#include <QDeclarativeItem>
-#include <QCloseEvent>
-#endif
 #include "kid3application.h"
 
-#if QT_VERSION < 0x050000
-//! @cond
-#define QQmlEngine QDeclarativeEngine
-#define QQuickView QmlView
-#define QQmlComponent QDeclarativeComponent
-#define QQmlError QDeclarativeError
-//! @endcond
-#endif
-
-#if QT_VERSION < 0x050000
-Q_EXPORT_PLUGIN2(QmlCommandPlugin, QmlCommandPlugin)
-#endif
-
 /**
  * Constructor.
  *
  * @param parent parent object
  */
 QmlCommandPlugin::QmlCommandPlugin(QObject* parent) : QObject(parent),
-  m_app(0), m_qmlView(0), m_qmlEngine(0), m_showOutput(false)
+  m_app(nullptr), m_qmlView(nullptr), m_qmlEngine(nullptr), m_showOutput(false)
 {
   setObjectName(QLatin1String("QmlCommand"));
 }
 
-/**
- * Destructor.
- */
-QmlCommandPlugin::~QmlCommandPlugin()
-{
-}
-
 /**
  * Get keys of available user commands.
  * @return list of keys, ["qml", "qmlview"].
  */
 QStringList QmlCommandPlugin::userCommandKeys() const
 {
-  return QStringList() << QLatin1String("qml") << QLatin1String("qmlview");
+  return {QLatin1String("qml"), QLatin1String("qmlview")};
 }
 
 /**
@@ -103,11 +77,11 @@ void QmlCommandPlugin::cleanup()
     m_qmlView->close();
   }
   delete m_qmlView;
-  m_qmlView = 0;
+  m_qmlView = nullptr;
   delete m_qmlEngine;
-  m_qmlEngine = 0;
+  m_qmlEngine = nullptr;
   if (s_messageHandlerInstance == this) {
-    s_messageHandlerInstance = 0;
+    s_messageHandlerInstance = nullptr;
   }
 }
 
@@ -129,10 +103,12 @@ bool QmlCommandPlugin::startUserCommand(
         m_qmlView = new QQuickView;
         m_qmlView->setResizeMode(QQuickView::SizeRootObjectToView);
         setupQmlEngine(m_qmlView->engine());
-        connect(m_qmlView, SIGNAL(closing(QQuickCloseEvent*)),
+        // New style functor based connection is not possible because
+        // QQuickCloseEvent is not public (QTBUG-36453, QTBUG-55722).
+        connect(m_qmlView, SIGNAL(closing(QQuickCloseEvent*)), // clazy:exclude=old-style-connect
                 this, SLOT(onQmlViewClosing()));
-        connect(m_qmlView->engine(), SIGNAL(quit()),
-                this, SLOT(onQmlViewFinished()), Qt::QueuedConnection);
+        connect(m_qmlView->engine(), &QQmlEngine::quit,
+                this, &QmlCommandPlugin::onQmlViewFinished, Qt::QueuedConnection);
       }
       m_qmlView->engine()->rootContext()->setContextProperty(
             QLatin1String("args"), arguments);
@@ -143,7 +119,8 @@ bool QmlCommandPlugin::startUserCommand(
       } else {
         // Probably an error.
         if (m_showOutput && m_qmlView->status() == QQuickView::Error) {
-          foreach (const QQmlError& err, m_qmlView->errors()) {
+          const auto errs = m_qmlView->errors();
+          for (const QQmlError& err : errs) {
             emit commandOutput(err.toString());
           }
         }
@@ -155,7 +132,7 @@ bool QmlCommandPlugin::startUserCommand(
       m_showOutput = showOutput;
       if (!m_qmlEngine) {
         m_qmlEngine = new QQmlEngine;
-        connect(m_qmlEngine, SIGNAL(quit()), this, SLOT(onQmlEngineQuit()));
+        connect(m_qmlEngine, &QQmlEngine::quit, this, &QmlCommandPlugin::onQmlEngineQuit);
         setupQmlEngine(m_qmlEngine);
       }
       m_qmlEngine->rootContext()->setContextProperty(QLatin1String("args"),
@@ -167,7 +144,8 @@ bool QmlCommandPlugin::startUserCommand(
       } else {
         // Probably an error.
         if (m_showOutput && component.isError()) {
-          foreach (const QQmlError& err, component.errors()) {
+          const auto errs = component.errors();
+          for (const QQmlError& err : errs) {
             emit commandOutput(err.toString());
           }
         }
@@ -191,15 +169,9 @@ void QmlCommandPlugin::setupQmlEngine(QQmlEngine* engine)
     engine->addImportPath(pluginsDir.absolutePath());
   }
   engine->rootContext()->setContextProperty(QLatin1String("app"), m_app);
-#if QT_VERSION >= 0x050000
-  connect(engine, SIGNAL(warnings(QList<QQmlError>)),
-          this, SLOT(onEngineError(QList<QQmlError>)),
+  connect(engine, &QQmlEngine::warnings,
+          this, &QmlCommandPlugin::onEngineError,
           Qt::UniqueConnection);
-#else
-  connect(engine, SIGNAL(warnings(QList<QDeclarativeError>)),
-          this, SLOT(onEngineError(QList<QDeclarativeError>)),
-          Qt::UniqueConnection);
-#endif
 }
 
 /**
@@ -216,8 +188,8 @@ QObject* QmlCommandPlugin::qobject()
  */
 void QmlCommandPlugin::onEngineError(const QList<QQmlError>& errors)
 {
-  if (QQmlEngine* engine = qobject_cast<QQmlEngine*>(sender())) {
-    foreach (const QQmlError& err, errors) {
+  if (auto engine = qobject_cast<QQmlEngine*>(sender())) {
+    for (const QQmlError& err : errors) {
       emit commandOutput(err.toString());
     }
     engine->clearComponentCache();
@@ -230,7 +202,7 @@ void QmlCommandPlugin::onEngineError(const QList<QQmlError>& errors)
  */
 void QmlCommandPlugin::onQmlViewClosing()
 {
-  if (QQuickView* view = qobject_cast<QQuickView*>(sender())) {
+  if (auto view = qobject_cast<QQuickView*>(sender())) {
     // This will invoke destruction of the currently loaded QML code.
     view->setSource(QUrl());
     view->engine()->clearComponentCache();
@@ -245,16 +217,14 @@ void QmlCommandPlugin::onQmlViewFinished()
 {
   if (m_qmlView) {
     m_qmlView->close();
-#if QT_VERSION >= 0x050000
     // Unfortunately, calling close() on the QQuickView will not give a
     // QEvent::Close in an installed event filter, there is no closeEvent(),
     // closing() is not signalled. What remains is the hard way.
     // Calling m_qmlView->deleteLater() will cause a crash when the QML console
     // is started, a command executed (e.g. app.nextFile()), then .quit and
     // then a qml script is started.
-    m_qmlView = 0;
-    QTimer::singleShot(0, this, SLOT(onEngineFinished()));
-#endif
+    m_qmlView = nullptr;
+    QTimer::singleShot(0, this, &QmlCommandPlugin::onEngineFinished);
   }
 }
 
@@ -275,12 +245,8 @@ void QmlCommandPlugin::onQmlEngineQuit()
 void QmlCommandPlugin::onEngineFinished()
 {
   if (m_showOutput) {
-#if QT_VERSION >= 0x050000
-    qInstallMessageHandler(0);
-#else
-    qInstallMsgHandler(0);
-#endif
-    s_messageHandlerInstance = 0;
+    qInstallMessageHandler(nullptr);
+    s_messageHandlerInstance = nullptr;
   }
 }
 
@@ -291,60 +257,19 @@ void QmlCommandPlugin::onEngineReady()
 {
   if (m_showOutput) {
     s_messageHandlerInstance = this;
-#if QT_VERSION >= 0x050000
     qInstallMessageHandler(messageHandler);
-#else
-    qInstallMsgHandler(messageHandler);
-#endif
   }
 }
 
 /** Instance of QmlCommandPlugin running and generating messages. */
-QmlCommandPlugin* QmlCommandPlugin::s_messageHandlerInstance = 0;
+QmlCommandPlugin* QmlCommandPlugin::s_messageHandlerInstance = nullptr;
 
 /**
  * Message handler emitting commandOutput().
  */
-#if QT_VERSION >= 0x050000
 void QmlCommandPlugin::messageHandler(QtMsgType, const QMessageLogContext&, const QString& msg)
 {
   if (s_messageHandlerInstance) {
     emit s_messageHandlerInstance->commandOutput(msg);
   }
 }
-#else
-void QmlCommandPlugin::messageHandler(QtMsgType, const char* msg)
-{
-  if (s_messageHandlerInstance) {
-    emit s_messageHandlerInstance->commandOutput(QString::fromUtf8(msg));
-  }
-}
-#endif
-
-
-#if QT_VERSION < 0x050000
-/**
- * Constructor.
- * @param parent parent widget
- */
-QmlView::QmlView(QWidget* parent) : QDeclarativeView(parent)
-{
-}
-
-/**
- * Destructor.
- */
-QmlView::~QmlView()
-{
-}
-
-/**
- * Handle close event.
- * @param ev close event
- */
-void QmlView::closeEvent(QCloseEvent* ev)
-{
-  ev->accept();
-  emit closing(0);
-}
-#endif
