@@ -38,14 +38,13 @@ void TestDiscogsImporter::testQueryAlbums()
 {
   queryAlbums(QLatin1String("Wizard"), QLatin1String("Odin"));
 
-  QStandardItemModel* albumModel = m_importer->getAlbumListModel();
+  AlbumListModel* albumModel = m_importer->getAlbumListModel();
   QVERIFY(albumModel->rowCount() > 0);
-  auto  item = static_cast<AlbumListItem*>(albumModel->item(0, 0));
-  QVERIFY(item);
-  QVERIFY(item->type() == AlbumListItem::Type);
-  QCOMPARE(item->text(), QString(QLatin1String("Wizard - Odin")));
-  QCOMPARE(item->getCategory(), QString(QLatin1String("Wizard-Odin/release")));
-  QVERIFY(!item->getId().isEmpty());
+  QString text, category, id;
+  albumModel->getItem(0, text, category, id);
+  QCOMPARE(text, QString(QLatin1String("Wizard - Odin")));
+  QCOMPARE(category, QString(QLatin1String("Wizard-Odin/release")));
+  QVERIFY(!id.isEmpty());
 }
 
 void TestDiscogsImporter::testQueryTracks()
